"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runnerJobFilesRouter = void 0;
const tslib_1 = require("tslib");
const express_1 = tslib_1.__importDefault(require("express"));
const logger_1 = require("../../../helpers/logger");
const object_storage_1 = require("../../../lib/object-storage");
const video_path_manager_1 = require("../../../lib/video-path-manager");
const video_studio_1 = require("../../../lib/video-studio");
const middlewares_1 = require("../../../middlewares");
const runners_1 = require("../../../middlewares/validators/runners");
const job_files_1 = require("../../../middlewares/validators/runners/job-files");
const lTags = (0, logger_1.loggerTagsFactory)('api', 'runner');
const runnerJobFilesRouter = express_1.default.Router();
exports.runnerJobFilesRouter = runnerJobFilesRouter;
runnerJobFilesRouter.post('/jobs/:jobUUID/files/videos/:videoId/max-quality', middlewares_1.apiRateLimiter, (0, middlewares_1.asyncMiddleware)(runners_1.jobOfRunnerGetValidator), (0, middlewares_1.asyncMiddleware)(job_files_1.runnerJobGetVideoTranscodingFileValidator), (0, middlewares_1.asyncMiddleware)(getMaxQualityVideoFile));
runnerJobFilesRouter.post('/jobs/:jobUUID/files/videos/:videoId/previews/max-quality', middlewares_1.apiRateLimiter, (0, middlewares_1.asyncMiddleware)(runners_1.jobOfRunnerGetValidator), (0, middlewares_1.asyncMiddleware)(job_files_1.runnerJobGetVideoTranscodingFileValidator), getMaxQualityVideoPreview);
runnerJobFilesRouter.post('/jobs/:jobUUID/files/videos/:videoId/studio/task-files/:filename', middlewares_1.apiRateLimiter, (0, middlewares_1.asyncMiddleware)(runners_1.jobOfRunnerGetValidator), (0, middlewares_1.asyncMiddleware)(job_files_1.runnerJobGetVideoTranscodingFileValidator), job_files_1.runnerJobGetVideoStudioTaskFileValidator, getVideoStudioTaskFile);
function getMaxQualityVideoFile(req, res) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const runnerJob = res.locals.runnerJob;
        const runner = runnerJob.Runner;
        const video = res.locals.videoAll;
        logger_1.logger.info('Get max quality file of video %s of job %s for runner %s', video.uuid, runnerJob.uuid, runner.name, lTags(runner.name, runnerJob.id, runnerJob.type));
        const file = video.getMaxQualityFile();
        if (file.storage === 1) {
            if (file.isHLS()) {
                return (0, object_storage_1.proxifyHLS)({
                    req,
                    res,
                    filename: file.filename,
                    playlist: video.getHLSPlaylist(),
                    reinjectVideoFileToken: false,
                    video
                });
            }
            return (0, object_storage_1.proxifyWebTorrentFile)({
                req,
                res,
                filename: file.filename
            });
        }
        return video_path_manager_1.VideoPathManager.Instance.makeAvailableVideoFile(file, videoPath => {
            return res.sendFile(videoPath);
        });
    });
}
function getMaxQualityVideoPreview(req, res) {
    const runnerJob = res.locals.runnerJob;
    const runner = runnerJob.Runner;
    const video = res.locals.videoAll;
    logger_1.logger.info('Get max quality preview file of video %s of job %s for runner %s', video.uuid, runnerJob.uuid, runner.name, lTags(runner.name, runnerJob.id, runnerJob.type));
    const file = video.getPreview();
    return res.sendFile(file.getPath());
}
function getVideoStudioTaskFile(req, res) {
    const runnerJob = res.locals.runnerJob;
    const runner = runnerJob.Runner;
    const video = res.locals.videoAll;
    const filename = req.params.filename;
    logger_1.logger.info('Get video studio task file %s of video %s of job %s for runner %s', filename, video.uuid, runnerJob.uuid, runner.name, lTags(runner.name, runnerJob.id, runnerJob.type));
    return res.sendFile((0, video_studio_1.getStudioTaskFilePath)(filename));
}
//# sourceMappingURL=jobs-files.js.map