"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.manageRunnersRouter = void 0;
const tslib_1 = require("tslib");
const express_1 = tslib_1.__importDefault(require("express"));
const logger_1 = require("../../../helpers/logger");
const token_generator_1 = require("../../../helpers/token-generator");
const middlewares_1 = require("../../../middlewares");
const runners_1 = require("../../../middlewares/validators/runners");
const runner_1 = require("../../../models/runner/runner");
const lTags = (0, logger_1.loggerTagsFactory)('api', 'runner');
const manageRunnersRouter = express_1.default.Router();
exports.manageRunnersRouter = manageRunnersRouter;
manageRunnersRouter.post('/register', middlewares_1.apiRateLimiter, (0, middlewares_1.asyncMiddleware)(runners_1.registerRunnerValidator), (0, middlewares_1.asyncMiddleware)(registerRunner));
manageRunnersRouter.post('/unregister', middlewares_1.apiRateLimiter, (0, middlewares_1.asyncMiddleware)(runners_1.getRunnerFromTokenValidator), (0, middlewares_1.asyncMiddleware)(unregisterRunner));
manageRunnersRouter.delete('/:runnerId', middlewares_1.apiRateLimiter, middlewares_1.authenticate, (0, middlewares_1.ensureUserHasRight)(29), (0, middlewares_1.asyncMiddleware)(runners_1.deleteRunnerValidator), (0, middlewares_1.asyncMiddleware)(deleteRunner));
manageRunnersRouter.get('/', middlewares_1.apiRateLimiter, middlewares_1.authenticate, (0, middlewares_1.ensureUserHasRight)(29), middlewares_1.paginationValidator, middlewares_1.runnersSortValidator, middlewares_1.setDefaultSort, middlewares_1.setDefaultPagination, (0, middlewares_1.asyncMiddleware)(listRunners));
function registerRunner(req, res) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const body = req.body;
        const runnerToken = (0, token_generator_1.generateRunnerToken)();
        const runner = new runner_1.RunnerModel({
            runnerToken,
            name: body.name,
            description: body.description,
            lastContact: new Date(),
            ip: req.ip,
            runnerRegistrationTokenId: res.locals.runnerRegistrationToken.id
        });
        yield runner.save();
        logger_1.logger.info('Registered new runner %s', runner.name, Object.assign({}, lTags(runner.name)));
        return res.json({ id: runner.id, runnerToken });
    });
}
function unregisterRunner(req, res) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const runner = res.locals.runner;
        yield runner.destroy();
        logger_1.logger.info('Unregistered runner %s', runner.name, Object.assign({}, lTags(runner.name)));
        return res.sendStatus(204);
    });
}
function deleteRunner(req, res) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const runner = res.locals.runner;
        yield runner.destroy();
        logger_1.logger.info('Deleted runner %s', runner.name, Object.assign({}, lTags(runner.name)));
        return res.sendStatus(204);
    });
}
function listRunners(req, res) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const query = req.query;
        const resultList = yield runner_1.RunnerModel.listForApi({
            start: query.start,
            count: query.count,
            sort: query.sort
        });
        return res.json({
            total: resultList.total,
            data: resultList.data.map(d => d.toFormattedJSON())
        });
    });
}
//# sourceMappingURL=manage-runners.js.map