"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runnerRegistrationTokensRouter = void 0;
const tslib_1 = require("tslib");
const express_1 = tslib_1.__importDefault(require("express"));
const logger_1 = require("../../../helpers/logger");
const token_generator_1 = require("../../../helpers/token-generator");
const middlewares_1 = require("../../../middlewares");
const runners_1 = require("../../../middlewares/validators/runners");
const runner_registration_token_1 = require("../../../models/runner/runner-registration-token");
const lTags = (0, logger_1.loggerTagsFactory)('api', 'runner');
const runnerRegistrationTokensRouter = express_1.default.Router();
exports.runnerRegistrationTokensRouter = runnerRegistrationTokensRouter;
runnerRegistrationTokensRouter.post('/registration-tokens/generate', middlewares_1.apiRateLimiter, middlewares_1.authenticate, (0, middlewares_1.ensureUserHasRight)(29), (0, middlewares_1.asyncMiddleware)(generateRegistrationToken));
runnerRegistrationTokensRouter.delete('/registration-tokens/:id', middlewares_1.apiRateLimiter, middlewares_1.authenticate, (0, middlewares_1.ensureUserHasRight)(29), (0, middlewares_1.asyncMiddleware)(runners_1.deleteRegistrationTokenValidator), (0, middlewares_1.asyncMiddleware)(deleteRegistrationToken));
runnerRegistrationTokensRouter.get('/registration-tokens', middlewares_1.apiRateLimiter, middlewares_1.authenticate, (0, middlewares_1.ensureUserHasRight)(29), middlewares_1.paginationValidator, middlewares_1.runnerRegistrationTokensSortValidator, middlewares_1.setDefaultSort, middlewares_1.setDefaultPagination, (0, middlewares_1.asyncMiddleware)(listRegistrationTokens));
function generateRegistrationToken(req, res) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        logger_1.logger.info('Generating new runner registration token.', lTags());
        const registrationToken = new runner_registration_token_1.RunnerRegistrationTokenModel({
            registrationToken: (0, token_generator_1.generateRunnerRegistrationToken)()
        });
        yield registrationToken.save();
        return res.sendStatus(204);
    });
}
function deleteRegistrationToken(req, res) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        logger_1.logger.info('Removing runner registration token.', lTags());
        const runnerRegistrationToken = res.locals.runnerRegistrationToken;
        yield runnerRegistrationToken.destroy();
        return res.sendStatus(204);
    });
}
function listRegistrationTokens(req, res) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const query = req.query;
        const resultList = yield runner_registration_token_1.RunnerRegistrationTokenModel.listForApi({
            start: query.start,
            count: query.count,
            sort: query.sort
        });
        return res.json({
            total: resultList.total,
            data: resultList.data.map(d => d.toFormattedJSON())
        });
    });
}
//# sourceMappingURL=registration-tokens.js.map