"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.emailVerificationRouter = void 0;
const tslib_1 = require("tslib");
const express_1 = tslib_1.__importDefault(require("express"));
const config_1 = require("../../../initializers/config");
const user_1 = require("../../../lib/user");
const middlewares_1 = require("../../../middlewares");
const validators_1 = require("../../../middlewares/validators");
const askSendEmailLimiter = (0, middlewares_1.buildRateLimiter)({
    windowMs: config_1.CONFIG.RATES_LIMIT.ASK_SEND_EMAIL.WINDOW_MS,
    max: config_1.CONFIG.RATES_LIMIT.ASK_SEND_EMAIL.MAX
});
const emailVerificationRouter = express_1.default.Router();
exports.emailVerificationRouter = emailVerificationRouter;
emailVerificationRouter.post(['/ask-send-verify-email', '/registrations/ask-send-verify-email'], askSendEmailLimiter, (0, middlewares_1.asyncMiddleware)(validators_1.usersAskSendVerifyEmailValidator), (0, middlewares_1.asyncMiddleware)(reSendVerifyUserEmail));
emailVerificationRouter.post('/:id/verify-email', (0, middlewares_1.asyncMiddleware)(validators_1.usersVerifyEmailValidator), (0, middlewares_1.asyncMiddleware)(verifyUserEmail));
emailVerificationRouter.post('/registrations/:registrationId/verify-email', (0, middlewares_1.asyncMiddleware)(validators_1.registrationVerifyEmailValidator), (0, middlewares_1.asyncMiddleware)(verifyRegistrationEmail));
function reSendVerifyUserEmail(req, res) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const user = res.locals.user;
        const registration = res.locals.userRegistration;
        if (user)
            yield (0, user_1.sendVerifyUserEmail)(user);
        else if (registration)
            yield (0, user_1.sendVerifyRegistrationEmail)(registration);
        return res.status(204).end();
    });
}
function verifyUserEmail(req, res) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const user = res.locals.user;
        user.emailVerified = true;
        if (req.body.isPendingEmail === true) {
            user.email = user.pendingEmail;
            user.pendingEmail = null;
        }
        yield user.save();
        return res.status(204).end();
    });
}
function verifyRegistrationEmail(req, res) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const registration = res.locals.userRegistration;
        registration.emailVerified = true;
        yield registration.save();
        return res.status(204).end();
    });
}
//# sourceMappingURL=email-verification.js.map