"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.studioRouter = void 0;
const tslib_1 = require("tslib");
const bluebird_1 = tslib_1.__importDefault(require("bluebird"));
const express_1 = tslib_1.__importDefault(require("express"));
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const express_utils_1 = require("../../../helpers/express-utils");
const constants_1 = require("../../../initializers/constants");
const video_studio_1 = require("../../../lib/video-studio");
const middlewares_1 = require("../../../middlewares");
const studioRouter = express_1.default.Router();
exports.studioRouter = studioRouter;
const tasksFiles = (0, express_utils_1.createAnyReqFiles)(constants_1.MIMETYPES.VIDEO.MIMETYPE_EXT, (req, file, cb) => {
    const body = req.body;
    const matches = file.fieldname.match(/tasks\[(\d+)\]/);
    if (!matches)
        return cb(new Error('Cannot find array element indice for ' + file.fieldname));
    const indice = parseInt(matches[1]);
    const task = body.tasks[indice];
    if (!task)
        return cb(new Error('Cannot find array element of indice ' + indice + ' for ' + file.fieldname));
    if (['add-intro', 'add-outro', 'add-watermark'].includes(task.name) &&
        file.fieldname === (0, video_studio_1.buildTaskFileFieldname)(indice)) {
        return cb(null, true);
    }
    return cb(null, false);
});
studioRouter.post('/:videoId/studio/edit', middlewares_1.authenticate, tasksFiles, (0, middlewares_1.asyncMiddleware)(middlewares_1.videoStudioAddEditionValidator), (0, middlewares_1.asyncMiddleware)(createEditionTasks));
function createEditionTasks(req, res) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const files = req.files;
        const body = req.body;
        const video = res.locals.videoAll;
        video.state = 9;
        yield video.save();
        const payload = {
            videoUUID: video.uuid,
            tasks: yield bluebird_1.default.mapSeries(body.tasks, (t, i) => buildTaskPayload(t, i, files))
        };
        yield (0, video_studio_1.createVideoStudioJob)({
            user: res.locals.oauth.token.User,
            payload,
            video
        });
        return res.sendStatus(204);
    });
}
const taskPayloadBuilders = {
    'add-intro': buildIntroOutroTask,
    'add-outro': buildIntroOutroTask,
    'cut': buildCutTask,
    'add-watermark': buildWatermarkTask
};
function buildTaskPayload(task, indice, files) {
    return taskPayloadBuilders[task.name](task, indice, files);
}
function buildIntroOutroTask(task, indice, files) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const destination = yield moveStudioFileToPersistentTMP((0, video_studio_1.getTaskFileFromReq)(files, indice).path);
        return {
            name: task.name,
            options: {
                file: destination
            }
        };
    });
}
function buildCutTask(task) {
    return Promise.resolve({
        name: task.name,
        options: {
            start: task.options.start,
            end: task.options.end
        }
    });
}
function buildWatermarkTask(task, indice, files) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const destination = yield moveStudioFileToPersistentTMP((0, video_studio_1.getTaskFileFromReq)(files, indice).path);
        return {
            name: task.name,
            options: {
                file: destination,
                watermarkSizeRatio: constants_1.VIDEO_FILTERS.WATERMARK.SIZE_RATIO,
                horitonzalMarginRatio: constants_1.VIDEO_FILTERS.WATERMARK.HORIZONTAL_MARGIN_RATIO,
                verticalMarginRatio: constants_1.VIDEO_FILTERS.WATERMARK.VERTICAL_MARGIN_RATIO
            }
        };
    });
}
function moveStudioFileToPersistentTMP(file) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const destination = (0, video_studio_1.getStudioTaskFilePath)((0, path_1.basename)(file));
        yield (0, fs_extra_1.move)(file, destination);
        return destination;
    });
}
//# sourceMappingURL=studio.js.map