"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transcodingRouter = void 0;
const tslib_1 = require("tslib");
const express_1 = tslib_1.__importDefault(require("express"));
const logger_1 = require("../../../helpers/logger");
const hooks_1 = require("../../../lib/plugins/hooks");
const create_transcoding_job_1 = require("../../../lib/transcoding/create-transcoding-job");
const transcoding_resolutions_1 = require("../../../lib/transcoding/transcoding-resolutions");
const middlewares_1 = require("../../../middlewares");
const lTags = (0, logger_1.loggerTagsFactory)('api', 'video');
const transcodingRouter = express_1.default.Router();
exports.transcodingRouter = transcodingRouter;
transcodingRouter.post('/:videoId/transcoding', middlewares_1.authenticate, (0, middlewares_1.ensureUserHasRight)(26), (0, middlewares_1.asyncMiddleware)(middlewares_1.createTranscodingValidator), (0, middlewares_1.asyncMiddleware)(createTranscoding));
function createTranscoding(req, res) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const video = res.locals.videoAll;
        logger_1.logger.info('Creating %s transcoding job for %s.', req.body.transcodingType, video.url, lTags());
        const body = req.body;
        const { resolution: maxResolution, hasAudio } = yield video.probeMaxQualityFile();
        const resolutions = yield hooks_1.Hooks.wrapObject((0, transcoding_resolutions_1.computeResolutionsToTranscode)({ input: maxResolution, type: 'vod', includeInput: true, strictLower: false, hasAudio }), 'filter:transcoding.manual.resolutions-to-transcode.result', body);
        if (resolutions.length === 0) {
            return res.sendStatus(204);
        }
        video.state = 2;
        yield video.save();
        yield (0, create_transcoding_job_1.createTranscodingJobs)({
            video,
            resolutions,
            transcodingType: body.transcodingType,
            isNewVideo: false,
            user: null
        });
        return res.sendStatus(204);
    });
}
//# sourceMappingURL=transcoding.js.map