"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.commentFeedsRouter = void 0;
const tslib_1 = require("tslib");
const express_1 = tslib_1.__importDefault(require("express"));
const markdown_1 = require("../../helpers/markdown");
const middlewares_1 = require("../../middlewares");
const config_1 = require("../../initializers/config");
const constants_1 = require("../../initializers/constants");
const middlewares_2 = require("../../middlewares");
const video_comment_1 = require("../../models/video/video-comment");
const shared_1 = require("./shared");
const commentFeedsRouter = express_1.default.Router();
exports.commentFeedsRouter = commentFeedsRouter;
const { middleware: cacheRouteMiddleware } = (0, middlewares_1.cacheRouteFactory)({
    headerBlacklist: ['Content-Type']
});
commentFeedsRouter.get('/feeds/video-comments.:format', middlewares_2.feedsFormatValidator, middlewares_2.setFeedFormatContentType, cacheRouteMiddleware(constants_1.ROUTE_CACHE_LIFETIME.FEEDS), (0, middlewares_2.asyncMiddleware)(middlewares_2.videoFeedsValidator), (0, middlewares_2.asyncMiddleware)(middlewares_2.videoCommentsFeedsValidator), (0, middlewares_2.asyncMiddleware)(generateVideoCommentsFeed));
function generateVideoCommentsFeed(req, res) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const start = 0;
        const video = res.locals.videoAll;
        const account = res.locals.account;
        const videoChannel = res.locals.videoChannel;
        const comments = yield video_comment_1.VideoCommentModel.listForFeed({
            start,
            count: config_1.CONFIG.FEEDS.COMMENTS.COUNT,
            videoId: video ? video.id : undefined,
            accountId: account ? account.id : undefined,
            videoChannelId: videoChannel ? videoChannel.id : undefined
        });
        const { name, description, imageUrl, link } = yield (0, shared_1.buildFeedMetadata)({ video, account, videoChannel });
        const feed = (0, shared_1.initFeed)({
            name,
            description,
            imageUrl,
            isPodcast: false,
            link,
            resourceType: 'video-comments',
            queryString: new URL(constants_1.WEBSERVER.URL + req.originalUrl).search
        });
        for (const comment of comments) {
            const localLink = constants_1.WEBSERVER.URL + comment.getCommentStaticPath();
            let title = comment.Video.name;
            const author = [];
            if (comment.Account) {
                title += ` - ${comment.Account.getDisplayName()}`;
                author.push({
                    name: comment.Account.getDisplayName(),
                    link: comment.Account.Actor.url
                });
            }
            feed.addItem({
                title,
                id: localLink,
                link: localLink,
                content: (0, markdown_1.toSafeHtml)(comment.text),
                author,
                date: comment.createdAt
            });
        }
        return (0, shared_1.sendFeed)(feed, req, res);
    });
}
//# sourceMappingURL=comment-feeds.js.map