"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildFeedMetadata = exports.sendFeed = exports.initFeed = void 0;
const tslib_1 = require("tslib");
const feed_1 = require("@peertube/feed");
const markdown_1 = require("../../../helpers/markdown");
const config_1 = require("../../../initializers/config");
const constants_1 = require("../../../initializers/constants");
const actor_image_1 = require("../../../lib/actor-image");
const user_1 = require("../../../models/user/user");
const core_utils_1 = require("../../../../shared/core-utils");
function initFeed(parameters) {
    const webserverUrl = constants_1.WEBSERVER.URL;
    const { name, description, link, imageUrl, isPodcast, resourceType, queryString, medium } = parameters;
    return new feed_1.Feed(Object.assign({ title: name, description: (0, markdown_1.mdToOneLinePlainText)(description), id: link || webserverUrl, link: link || webserverUrl, image: imageUrl, favicon: webserverUrl + '/client/assets/images/favicon.png', copyright: `All rights reserved, unless otherwise specified in the terms specified at ${webserverUrl}/about` +
            ` and potential licenses granted by each content's rightholder.`, generator: `Toraifōsu`, medium: medium || 'video', feedLinks: {
            json: `${webserverUrl}/feeds/${resourceType}.json${queryString}`,
            atom: `${webserverUrl}/feeds/${resourceType}.atom${queryString}`,
            rss: isPodcast
                ? `${webserverUrl}/feeds/podcast/videos.xml${queryString}`
                : `${webserverUrl}/feeds/${resourceType}.xml${queryString}`
        } }, (0, core_utils_1.pick)(parameters, ['stunServers', 'trackers', 'customXMLNS', 'customTags', 'author', 'person', 'locked'])));
}
exports.initFeed = initFeed;
function sendFeed(feed, req, res) {
    const format = req.params.format;
    if (format === 'atom' || format === 'atom1') {
        return res.send(feed.atom1()).end();
    }
    if (format === 'json' || format === 'json1') {
        return res.send(feed.json1()).end();
    }
    if (format === 'rss' || format === 'rss2') {
        return res.send(feed.rss2()).end();
    }
    if (req.query.format === 'atom' || req.query.format === 'atom1') {
        return res.send(feed.atom1()).end();
    }
    return res.send(feed.rss2()).end();
}
exports.sendFeed = sendFeed;
function buildFeedMetadata(options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { video, videoChannel, account } = options;
        let imageUrl = constants_1.WEBSERVER.URL + '/client/assets/images/icons/icon-96x96.png';
        let accountImageUrl;
        let name;
        let userName;
        let description;
        let email;
        let link;
        let accountLink;
        let user;
        if (videoChannel) {
            name = videoChannel.getDisplayName();
            description = videoChannel.description;
            link = videoChannel.getClientUrl();
            accountLink = videoChannel.Account.getClientUrl();
            if (videoChannel.Actor.hasImage(1)) {
                const videoChannelAvatar = (0, actor_image_1.getBiggestActorImage)(videoChannel.Actor.Avatars);
                imageUrl = constants_1.WEBSERVER.URL + videoChannelAvatar.getStaticPath();
            }
            if (videoChannel.Account.Actor.hasImage(1)) {
                const accountAvatar = (0, actor_image_1.getBiggestActorImage)(videoChannel.Account.Actor.Avatars);
                accountImageUrl = constants_1.WEBSERVER.URL + accountAvatar.getStaticPath();
            }
            user = yield user_1.UserModel.loadById(videoChannel.Account.userId);
            userName = videoChannel.Account.getDisplayName();
        }
        else if (account) {
            name = account.getDisplayName();
            description = account.description;
            link = account.getClientUrl();
            accountLink = link;
            if (account.Actor.hasImage(1)) {
                const accountAvatar = (0, actor_image_1.getBiggestActorImage)(account.Actor.Avatars);
                imageUrl = constants_1.WEBSERVER.URL + (accountAvatar === null || accountAvatar === void 0 ? void 0 : accountAvatar.getStaticPath());
                accountImageUrl = imageUrl;
            }
            user = yield user_1.UserModel.loadById(account.userId);
        }
        else if (video) {
            name = video.name;
            description = video.description;
            link = video.url;
        }
        else {
            name = config_1.CONFIG.INSTANCE.NAME;
            description = config_1.CONFIG.INSTANCE.DESCRIPTION;
            link = constants_1.WEBSERVER.URL;
        }
        if (user && !user.pluginAuth && user.emailVerified && user.emailPublic) {
            email = user.email;
        }
        return { name, userName, description, imageUrl, accountImageUrl, email, link, accountLink };
    });
}
exports.buildFeedMetadata = buildFeedMetadata;
//# sourceMappingURL=common-feed-utils.js.map