"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCommonVideoFeedAttributes = exports.getVideosForFeeds = void 0;
const tslib_1 = require("tslib");
const markdown_1 = require("../../../helpers/markdown");
const config_1 = require("../../../initializers/config");
const constants_1 = require("../../../initializers/constants");
const application_1 = require("../../../models/application/application");
const video_format_utils_1 = require("../../../models/video/formatter/video-format-utils");
const video_1 = require("../../../models/video/video");
function getVideosForFeeds(options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const server = yield (0, application_1.getServerActor)();
        const { data } = yield video_1.VideoModel.listForApi(Object.assign({ start: 0, count: config_1.CONFIG.FEEDS.VIDEOS.COUNT, displayOnlyForFollower: {
                actorId: server.id,
                orLocalVideos: true
            }, hasFiles: true, countVideos: false }, options));
        return data;
    });
}
exports.getVideosForFeeds = getVideosForFeeds;
function getCommonVideoFeedAttributes(video) {
    const localLink = constants_1.WEBSERVER.URL + video.getWatchStaticPath();
    const thumbnailModels = [];
    if (video.hasPreview())
        thumbnailModels.push(video.getPreview());
    thumbnailModels.push(video.getMiniature());
    return {
        title: video.name,
        link: localLink,
        description: (0, markdown_1.mdToOneLinePlainText)(video.getTruncatedDescription()),
        content: (0, markdown_1.toSafeHtml)(video.description),
        date: video.publishedAt,
        nsfw: video.nsfw,
        category: video.category
            ? [{ name: (0, video_format_utils_1.getCategoryLabel)(video.category) }]
            : undefined,
        thumbnails: thumbnailModels.map(t => ({
            url: constants_1.WEBSERVER.URL + t.getLocalStaticPath(),
            width: t.width,
            height: t.height
        }))
    };
}
exports.getCommonVideoFeedAttributes = getCommonVideoFeedAttributes;
//# sourceMappingURL=video-feed-utils.js.map