"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.videoFeedsRouter = void 0;
const tslib_1 = require("tslib");
const express_1 = tslib_1.__importDefault(require("express"));
const path_1 = require("path");
const middlewares_1 = require("../../middlewares");
const express_utils_1 = require("../../helpers/express-utils");
const constants_1 = require("../../initializers/constants");
const middlewares_2 = require("../../middlewares");
const shared_1 = require("./shared");
const videoFeedsRouter = express_1.default.Router();
exports.videoFeedsRouter = videoFeedsRouter;
const { middleware: cacheRouteMiddleware } = (0, middlewares_1.cacheRouteFactory)({
    headerBlacklist: ['Content-Type']
});
videoFeedsRouter.get('/feeds/videos.:format', middlewares_2.videosSortValidator, middlewares_2.setDefaultVideosSort, middlewares_2.feedsFormatValidator, middlewares_2.setFeedFormatContentType, cacheRouteMiddleware(constants_1.ROUTE_CACHE_LIFETIME.FEEDS), middlewares_2.commonVideosFiltersValidator, (0, middlewares_2.asyncMiddleware)(middlewares_2.videoFeedsValidator), (0, middlewares_2.asyncMiddleware)(generateVideoFeed));
videoFeedsRouter.get('/feeds/subscriptions.:format', middlewares_2.videosSortValidator, middlewares_2.setDefaultVideosSort, middlewares_2.feedsFormatValidator, middlewares_2.setFeedFormatContentType, cacheRouteMiddleware(constants_1.ROUTE_CACHE_LIFETIME.FEEDS), middlewares_2.commonVideosFiltersValidator, (0, middlewares_2.asyncMiddleware)(middlewares_2.videoSubscriptionFeedsValidator), (0, middlewares_2.asyncMiddleware)(generateVideoFeedForSubscriptions));
function generateVideoFeed(req, res) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const account = res.locals.account;
        const videoChannel = res.locals.videoChannel;
        const { name, description, imageUrl, accountImageUrl, link, accountLink } = yield (0, shared_1.buildFeedMetadata)({ videoChannel, account });
        const feed = (0, shared_1.initFeed)({
            name,
            description,
            link,
            isPodcast: false,
            imageUrl,
            author: { name, link: accountLink, imageUrl: accountImageUrl },
            resourceType: 'videos',
            queryString: new URL(constants_1.WEBSERVER.URL + req.url).search
        });
        const data = yield (0, shared_1.getVideosForFeeds)({
            sort: req.query.sort,
            nsfw: (0, express_utils_1.buildNSFWFilter)(res, req.query.nsfw),
            isLocal: req.query.isLocal,
            include: req.query.include | 8,
            accountId: account === null || account === void 0 ? void 0 : account.id,
            videoChannelId: videoChannel === null || videoChannel === void 0 ? void 0 : videoChannel.id
        });
        addVideosToFeed(feed, data);
        return (0, shared_1.sendFeed)(feed, req, res);
    });
}
function generateVideoFeedForSubscriptions(req, res) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const account = res.locals.account;
        const { name, description, imageUrl, link } = yield (0, shared_1.buildFeedMetadata)({ account });
        const feed = (0, shared_1.initFeed)({
            name,
            description,
            link,
            isPodcast: false,
            imageUrl,
            resourceType: 'videos',
            queryString: new URL(constants_1.WEBSERVER.URL + req.url).search
        });
        const data = yield (0, shared_1.getVideosForFeeds)({
            sort: req.query.sort,
            nsfw: (0, express_utils_1.buildNSFWFilter)(res, req.query.nsfw),
            isLocal: req.query.isLocal,
            include: req.query.include | 8,
            displayOnlyForFollower: {
                actorId: res.locals.user.Account.Actor.id,
                orLocalVideos: false
            },
            user: res.locals.user
        });
        addVideosToFeed(feed, data);
        return (0, shared_1.sendFeed)(feed, req, res);
    });
}
function addVideosToFeed(feed, videos) {
    for (const video of videos) {
        const formattedVideoFiles = video.getFormattedAllVideoFilesJSON(false);
        const torrents = formattedVideoFiles.map(videoFile => ({
            title: video.name,
            url: videoFile.torrentUrl,
            size_in_bytes: videoFile.size
        }));
        const videoFiles = formattedVideoFiles.map(videoFile => {
            return {
                type: constants_1.MIMETYPES.VIDEO.EXT_MIMETYPE[(0, path_1.extname)(videoFile.fileUrl)],
                medium: 'video',
                height: videoFile.resolution.id,
                fileSize: videoFile.size,
                url: videoFile.fileUrl,
                framerate: videoFile.fps,
                duration: video.duration,
                lang: video.language
            };
        });
        feed.addItem(Object.assign(Object.assign({}, (0, shared_1.getCommonVideoFeedAttributes)(video)), { id: constants_1.WEBSERVER.URL + video.getWatchStaticPath(), author: [
                {
                    name: video.VideoChannel.getDisplayName(),
                    link: video.VideoChannel.getClientUrl()
                }
            ], torrents, video: videoFiles.length !== 0
                ? {
                    url: videoFiles[0].url,
                    length: videoFiles[0].fileSize,
                    type: videoFiles[0].type
                }
                : undefined, videos: videoFiles, embed: {
                url: constants_1.WEBSERVER.URL + video.getEmbedStaticPath(),
                allowFullscreen: true
            }, player: {
                url: constants_1.WEBSERVER.URL + video.getWatchStaticPath()
            }, community: {
                statistics: {
                    views: video.views
                }
            } }));
    }
}
//# sourceMappingURL=video-feeds.js.map