"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.objectStorageProxyRouter = void 0;
const tslib_1 = require("tslib");
const cors_1 = tslib_1.__importDefault(require("cors"));
const express_1 = tslib_1.__importDefault(require("express"));
const constants_1 = require("../initializers/constants");
const object_storage_1 = require("../lib/object-storage");
const middlewares_1 = require("../middlewares");
const m3u8_playlist_1 = require("./shared/m3u8-playlist");
const objectStorageProxyRouter = express_1.default.Router();
exports.objectStorageProxyRouter = objectStorageProxyRouter;
objectStorageProxyRouter.use((0, cors_1.default)());
objectStorageProxyRouter.get(constants_1.OBJECT_STORAGE_PROXY_PATHS.PRIVATE_WEBSEED + ':filename', middlewares_1.ensurePrivateObjectStorageProxyIsEnabled, middlewares_1.optionalAuthenticate, (0, middlewares_1.asyncMiddleware)(middlewares_1.ensureCanAccessVideoPrivateWebTorrentFiles), (0, middlewares_1.asyncMiddleware)(proxifyWebTorrentController));
objectStorageProxyRouter.get(constants_1.OBJECT_STORAGE_PROXY_PATHS.STREAMING_PLAYLISTS.PRIVATE_HLS + ':videoUUID/:filename', middlewares_1.ensurePrivateObjectStorageProxyIsEnabled, middlewares_1.optionalAuthenticate, (0, middlewares_1.asyncMiddleware)(middlewares_1.ensureCanAccessPrivateVideoHLSFiles), (0, middlewares_1.asyncMiddleware)(proxifyHLSController));
function proxifyWebTorrentController(req, res) {
    const filename = req.params.filename;
    return (0, object_storage_1.proxifyWebTorrentFile)({ req, res, filename });
}
function proxifyHLSController(req, res) {
    const playlist = res.locals.videoStreamingPlaylist;
    const video = res.locals.onlyVideo;
    const filename = req.params.filename;
    const reinjectVideoFileToken = filename.endsWith('.m3u8') && (0, m3u8_playlist_1.doReinjectVideoFileToken)(req);
    return (0, object_storage_1.proxifyHLS)({
        req,
        res,
        playlist,
        video,
        filename,
        reinjectVideoFileToken
    });
}
//# sourceMappingURL=object-storage-proxy.js.map