"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isRunnerJobAbortReasonValid = exports.isRunnerJobProgressValid = exports.isRunnerJobErrorMessageValid = exports.isRunnerJobTokenValid = exports.isRunnerJobUpdatePayloadValid = exports.isRunnerJobSuccessPayloadValid = exports.isRunnerJobTypeValid = void 0;
const tslib_1 = require("tslib");
const validator_1 = tslib_1.__importDefault(require("validator"));
const constants_1 = require("../../../initializers/constants");
const misc_1 = require("../misc");
const RUNNER_JOBS_CONSTRAINTS_FIELDS = constants_1.CONSTRAINTS_FIELDS.RUNNER_JOBS;
const runnerJobTypes = new Set(['vod-hls-transcoding', 'vod-web-video-transcoding', 'vod-audio-merge-transcoding']);
function isRunnerJobTypeValid(value) {
    return runnerJobTypes.has(value);
}
exports.isRunnerJobTypeValid = isRunnerJobTypeValid;
function isRunnerJobSuccessPayloadValid(value, type, files) {
    return isRunnerJobVODWebVideoResultPayloadValid(value, type, files) ||
        isRunnerJobVODHLSResultPayloadValid(value, type, files) ||
        isRunnerJobVODAudioMergeResultPayloadValid(value, type, files) ||
        isRunnerJobLiveRTMPHLSResultPayloadValid(value, type) ||
        isRunnerJobVideoStudioResultPayloadValid(value, type, files);
}
exports.isRunnerJobSuccessPayloadValid = isRunnerJobSuccessPayloadValid;
function isRunnerJobProgressValid(value) {
    return validator_1.default.isInt(value + '', RUNNER_JOBS_CONSTRAINTS_FIELDS.PROGRESS);
}
exports.isRunnerJobProgressValid = isRunnerJobProgressValid;
function isRunnerJobUpdatePayloadValid(value, type, files) {
    return isRunnerJobVODWebVideoUpdatePayloadValid(value, type, files) ||
        isRunnerJobVODHLSUpdatePayloadValid(value, type, files) ||
        isRunnerJobVideoStudioUpdatePayloadValid(value, type, files) ||
        isRunnerJobVODAudioMergeUpdatePayloadValid(value, type, files) ||
        isRunnerJobLiveRTMPHLSUpdatePayloadValid(value, type, files);
}
exports.isRunnerJobUpdatePayloadValid = isRunnerJobUpdatePayloadValid;
function isRunnerJobTokenValid(value) {
    return (0, misc_1.exists)(value) && validator_1.default.isLength(value, RUNNER_JOBS_CONSTRAINTS_FIELDS.TOKEN);
}
exports.isRunnerJobTokenValid = isRunnerJobTokenValid;
function isRunnerJobAbortReasonValid(value) {
    return validator_1.default.isLength(value, RUNNER_JOBS_CONSTRAINTS_FIELDS.REASON);
}
exports.isRunnerJobAbortReasonValid = isRunnerJobAbortReasonValid;
function isRunnerJobErrorMessageValid(value) {
    return validator_1.default.isLength(value, RUNNER_JOBS_CONSTRAINTS_FIELDS.ERROR_MESSAGE);
}
exports.isRunnerJobErrorMessageValid = isRunnerJobErrorMessageValid;
function isRunnerJobVODWebVideoResultPayloadValid(_value, type, files) {
    return type === 'vod-web-video-transcoding' &&
        (0, misc_1.isFileValid)({ files, field: 'payload[videoFile]', mimeTypeRegex: null, maxSize: null });
}
function isRunnerJobVODHLSResultPayloadValid(_value, type, files) {
    return type === 'vod-hls-transcoding' &&
        (0, misc_1.isFileValid)({ files, field: 'payload[videoFile]', mimeTypeRegex: null, maxSize: null }) &&
        (0, misc_1.isFileValid)({ files, field: 'payload[resolutionPlaylistFile]', mimeTypeRegex: null, maxSize: null });
}
function isRunnerJobVODAudioMergeResultPayloadValid(_value, type, files) {
    return type === 'vod-audio-merge-transcoding' &&
        (0, misc_1.isFileValid)({ files, field: 'payload[videoFile]', mimeTypeRegex: null, maxSize: null });
}
function isRunnerJobLiveRTMPHLSResultPayloadValid(value, type) {
    return type === 'live-rtmp-hls-transcoding' && (!value || (typeof value === 'object' && Object.keys(value).length === 0));
}
function isRunnerJobVideoStudioResultPayloadValid(_value, type, files) {
    return type === 'video-studio-transcoding' &&
        (0, misc_1.isFileValid)({ files, field: 'payload[videoFile]', mimeTypeRegex: null, maxSize: null });
}
function isRunnerJobVODWebVideoUpdatePayloadValid(value, type, _files) {
    return type === 'vod-web-video-transcoding' &&
        (!value || (typeof value === 'object' && Object.keys(value).length === 0));
}
function isRunnerJobVODHLSUpdatePayloadValid(value, type, _files) {
    return type === 'vod-hls-transcoding' &&
        (!value || (typeof value === 'object' && Object.keys(value).length === 0));
}
function isRunnerJobVODAudioMergeUpdatePayloadValid(value, type, _files) {
    return type === 'vod-audio-merge-transcoding' &&
        (!value || (typeof value === 'object' && Object.keys(value).length === 0));
}
function isRunnerJobLiveRTMPHLSUpdatePayloadValid(value, type, files) {
    let result = type === 'live-rtmp-hls-transcoding' && !!value && !!files;
    result && (result = (0, misc_1.isFileValid)({ files, field: 'payload[masterPlaylistFile]', mimeTypeRegex: null, maxSize: null, optional: true }));
    result && (result = (0, misc_1.isFileValid)({
        files,
        field: 'payload[resolutionPlaylistFile]',
        mimeTypeRegex: null,
        maxSize: null,
        optional: !value.resolutionPlaylistFilename
    }));
    if (files['payload[resolutionPlaylistFile]']) {
        result && (result = (0, misc_1.isSafeFilename)(value.resolutionPlaylistFilename, 'm3u8'));
    }
    return result &&
        (0, misc_1.isSafeFilename)(value.videoChunkFilename, 'ts') &&
        ((value.type === 'remove-chunk') ||
            (value.type === 'add-chunk' &&
                (0, misc_1.isFileValid)({ files, field: 'payload[videoChunkFile]', mimeTypeRegex: null, maxSize: null })));
}
function isRunnerJobVideoStudioUpdatePayloadValid(value, type, _files) {
    return type === 'video-studio-transcoding' &&
        (!value || (typeof value === 'object' && Object.keys(value).length === 0));
}
//# sourceMappingURL=jobs.js.map