"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.down = exports.up = void 0;
const tslib_1 = require("tslib");
const Sequelize = tslib_1.__importStar(require("sequelize"));
function up(utils) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        {
            const query = `
    CREATE TABLE IF NOT EXISTS "videoLiveReplaySetting" (
      "id"   SERIAL ,
      "privacy" INTEGER NOT NULL,
      "createdAt" TIMESTAMP WITH TIME ZONE NOT NULL,
      "updatedAt" TIMESTAMP WITH TIME ZONE NOT NULL,
      PRIMARY KEY ("id")
      );
    `;
            yield utils.sequelize.query(query, { transaction: utils.transaction });
        }
        {
            yield utils.queryInterface.addColumn('videoLive', 'replaySettingId', {
                type: Sequelize.INTEGER,
                defaultValue: null,
                allowNull: true,
                references: {
                    model: 'videoLiveReplaySetting',
                    key: 'id'
                },
                onDelete: 'SET NULL'
            }, { transaction: utils.transaction });
        }
        {
            yield utils.queryInterface.addColumn('videoLiveSession', 'replaySettingId', {
                type: Sequelize.INTEGER,
                defaultValue: null,
                allowNull: true,
                references: {
                    model: 'videoLiveReplaySetting',
                    key: 'id'
                },
                onDelete: 'SET NULL'
            }, { transaction: utils.transaction });
        }
        {
            const query = `
    SELECT live."id", v."privacy"
    FROM "videoLive" live
    INNER JOIN "video" v ON live."videoId" = v."id"
    WHERE live."saveReplay" = true
    `;
            const videoLives = yield utils.sequelize.query(query, { type: Sequelize.QueryTypes.SELECT, transaction: utils.transaction });
            for (const videoLive of videoLives) {
                const query = `
      WITH new_replay_setting AS (
        INSERT INTO "videoLiveReplaySetting" ("privacy", "createdAt", "updatedAt")
        VALUES (:privacy, NOW(), NOW())
        RETURNING id
        )
      UPDATE "videoLive" SET "replaySettingId" = (SELECT id FROM new_replay_setting)
      WHERE "id" = :id
      `;
                const options = {
                    replacements: { privacy: videoLive.privacy, id: videoLive.id },
                    type: Sequelize.QueryTypes.UPDATE,
                    transaction: utils.transaction
                };
                yield utils.sequelize.query(query, options);
            }
        }
        {
            const query = `
    SELECT session."id", v."privacy"
    FROM "videoLiveSession" session
    INNER JOIN "video" v ON session."liveVideoId" = v."id"
    WHERE session."saveReplay" = true
      AND session."liveVideoId" IS NOT NULL;
    `;
            const videoLiveSessions = yield utils.sequelize.query(query, { type: Sequelize.QueryTypes.SELECT, transaction: utils.transaction });
            for (const videoLive of videoLiveSessions) {
                const query = `
      WITH new_replay_setting AS (
        INSERT INTO "videoLiveReplaySetting" ("privacy", "createdAt", "updatedAt")
        VALUES (:privacy, NOW(), NOW())
        RETURNING id
        )
      UPDATE "videoLiveSession" SET "replaySettingId" = (SELECT id FROM new_replay_setting)
      WHERE "id" = :id
      `;
                const options = {
                    replacements: { privacy: videoLive.privacy, id: videoLive.id },
                    type: Sequelize.QueryTypes.UPDATE,
                    transaction: utils.transaction
                };
                yield utils.sequelize.query(query, options);
            }
        }
    });
}
exports.up = up;
function down(options) {
    throw new Error('Not implemented.');
}
exports.down = down;
//# sourceMappingURL=0760-video-live-replay-setting.js.map