"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processTranscodingJobBuilder = void 0;
const tslib_1 = require("tslib");
const create_transcoding_job_1 = require("../../transcoding/create-transcoding-job");
const user_1 = require("../../../models/user/user");
const video_1 = require("../../../models/video/video");
const video_job_info_1 = require("../../../models/video/video-job-info");
const core_utils_1 = require("../../../../shared/core-utils");
const logger_1 = require("../../../helpers/logger");
const job_queue_1 = require("../job-queue");
function processTranscodingJobBuilder(job) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const payload = job.data;
        logger_1.logger.info('Processing transcoding job builder in job %s.', job.id);
        if (payload.optimizeJob) {
            const video = yield video_1.VideoModel.loadFull(payload.videoUUID);
            const user = yield user_1.UserModel.loadByVideoId(video.id);
            const videoFile = video.getMaxQualityFile();
            yield (0, create_transcoding_job_1.createOptimizeOrMergeAudioJobs)(Object.assign(Object.assign({}, (0, core_utils_1.pick)(payload.optimizeJob, ['isNewVideo'])), { video,
                videoFile,
                user, videoFileAlreadyLocked: false }));
        }
        for (const job of (payload.jobs || [])) {
            yield job_queue_1.JobQueue.Instance.createJob(job);
            yield video_job_info_1.VideoJobInfoModel.increaseOrCreate(payload.videoUUID, 'pendingTranscode');
        }
        for (const sequentialJobs of (payload.sequentialJobs || [])) {
            yield job_queue_1.JobQueue.Instance.createSequentialJobFlow(...sequentialJobs);
            yield video_job_info_1.VideoJobInfoModel.increaseOrCreate(payload.videoUUID, 'pendingTranscode', sequentialJobs.filter(s => !!s).length);
        }
    });
}
exports.processTranscodingJobBuilder = processTranscodingJobBuilder;
//# sourceMappingURL=transcoding-job-builder.js.map