"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FFmpegTranscodingWrapper = void 0;
const tslib_1 = require("tslib");
const ffmpeg_1 = require("../../../../helpers/ffmpeg");
const logger_1 = require("../../../../helpers/logger");
const config_1 = require("../../../../initializers/config");
const constants_1 = require("../../../../initializers/constants");
const default_transcoding_profiles_1 = require("../../../transcoding/default-transcoding-profiles");
const ffmpeg_2 = require("../../../../../shared/ffmpeg");
const live_utils_1 = require("../../live-utils");
const abstract_transcoding_wrapper_1 = require("./abstract-transcoding-wrapper");
class FFmpegTranscodingWrapper extends abstract_transcoding_wrapper_1.AbstractTranscodingWrapper {
    constructor() {
        super(...arguments);
        this.aborted = false;
        this.errored = false;
        this.ended = false;
    }
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this.ffmpegCommand = config_1.CONFIG.LIVE.TRANSCODING.ENABLED
                ? yield this.buildFFmpegLive().getLiveTranscodingCommand({
                    inputUrl: this.inputLocalUrl,
                    outPath: this.outDirectory,
                    masterPlaylistName: this.streamingPlaylist.playlistFilename,
                    segmentListSize: this.segmentListSize,
                    segmentDuration: this.segmentDuration,
                    toTranscode: this.toTranscode,
                    bitrate: this.bitrate,
                    ratio: this.ratio,
                    hasAudio: this.hasAudio
                })
                : this.buildFFmpegLive().getLiveMuxingCommand({
                    inputUrl: this.inputLocalUrl,
                    outPath: this.outDirectory,
                    masterPlaylistName: this.streamingPlaylist.playlistFilename,
                    segmentListSize: constants_1.VIDEO_LIVE.SEGMENTS_LIST_SIZE,
                    segmentDuration: (0, live_utils_1.getLiveSegmentTime)(this.videoLive.latencyMode)
                });
            logger_1.logger.info('Running local live muxing/transcoding for %s.', this.videoUUID, this.lTags());
            let ffmpegShellCommand;
            this.ffmpegCommand.on('start', cmdline => {
                ffmpegShellCommand = cmdline;
                logger_1.logger.debug('Running ffmpeg command for live', Object.assign({ ffmpegShellCommand }, this.lTags()));
            });
            this.ffmpegCommand.on('error', (err, stdout, stderr) => {
                this.onFFmpegError({ err, stdout, stderr, ffmpegShellCommand });
            });
            this.ffmpegCommand.on('end', () => {
                this.onFFmpegEnded();
            });
            this.ffmpegCommand.run();
        });
    }
    abort() {
        if (this.ended || this.errored || this.aborted)
            return;
        logger_1.logger.debug('Killing ffmpeg after live abort of ' + this.videoUUID, this.lTags());
        this.ffmpegCommand.kill('SIGINT');
        this.aborted = true;
        this.emit('end');
    }
    onFFmpegError(options) {
        var _a;
        const { err, stdout, stderr, ffmpegShellCommand } = options;
        if ((_a = err === null || err === void 0 ? void 0 : err.message) === null || _a === void 0 ? void 0 : _a.includes('Exiting normally'))
            return;
        if (this.ended || this.errored || this.aborted)
            return;
        logger_1.logger.error('FFmpeg transcoding error.', Object.assign({ err, stdout, stderr, ffmpegShellCommand }, this.lTags()));
        this.errored = true;
        this.emit('error', { err });
    }
    onFFmpegEnded() {
        if (this.ended || this.errored || this.aborted)
            return;
        logger_1.logger.debug('Live ffmpeg transcoding ended for ' + this.videoUUID, this.lTags());
        this.ended = true;
        this.emit('end');
    }
    buildFFmpegLive() {
        return new ffmpeg_2.FFmpegLive((0, ffmpeg_1.getFFmpegCommandWrapperOptions)('live', default_transcoding_profiles_1.VideoTranscodingProfilesManager.Instance.getAvailableEncoders()));
    }
}
exports.FFmpegTranscodingWrapper = FFmpegTranscodingWrapper;
//# sourceMappingURL=ffmpeg-transcoding-wrapper.js.map