"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RegistrationRequestForModerators = void 0;
const tslib_1 = require("tslib");
const logger_1 = require("../../../../helpers/logger");
const user_1 = require("../../../../models/user/user");
const user_notification_1 = require("../../../../models/user/user-notification");
const abstract_notification_1 = require("../common/abstract-notification");
class RegistrationRequestForModerators extends abstract_notification_1.AbstractNotification {
    prepare() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this.moderators = yield user_1.UserModel.listWithRight(28);
        });
    }
    log() {
        logger_1.logger.info('Notifying %s moderators of new user registration request of %s.', this.moderators.length, this.payload.username);
    }
    getSetting(user) {
        return user.NotificationSetting.newUserRegistration;
    }
    getTargetUsers() {
        return this.moderators;
    }
    createNotification(user) {
        const notification = user_notification_1.UserNotificationModel.build({
            type: 20,
            userId: user.id,
            userRegistrationId: this.payload.id
        });
        notification.UserRegistration = this.payload;
        return notification;
    }
    createEmail(to) {
        return {
            template: 'user-registration-request',
            to,
            subject: `A new user wants to register: ${this.payload.username}`,
            locals: {
                registration: this.payload
            }
        };
    }
}
exports.RegistrationRequestForModerators = RegistrationRequestForModerators;
//# sourceMappingURL=registration-request-for-moderators.js.map