"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AbstractVODTranscodingJobHandler = void 0;
const tslib_1 = require("tslib");
const database_utils_1 = require("../../../helpers/database-utils");
const logger_1 = require("../../../helpers/logger");
const video_state_1 = require("../../video-state");
const video_job_info_1 = require("../../../models/video/video-job-info");
const models_1 = require("../../../../shared/models");
const abstract_job_handler_1 = require("./abstract-job-handler");
const shared_1 = require("./shared");
class AbstractVODTranscodingJobHandler extends abstract_job_handler_1.AbstractJobHandler {
    isAbortSupported() {
        return true;
    }
    specificUpdate(_options) {
    }
    specificAbort(_options) {
    }
    specificError(options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (options.nextState !== models_1.RunnerJobState.ERRORED)
                return;
            const video = yield (0, shared_1.loadTranscodingRunnerVideo)(options.runnerJob, this.lTags);
            if (!video)
                return;
            yield (0, video_state_1.moveToFailedTranscodingState)(video);
            yield video_job_info_1.VideoJobInfoModel.decrease(video.uuid, 'pendingTranscode');
        });
    }
    specificCancel(options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { runnerJob } = options;
            const video = yield (0, shared_1.loadTranscodingRunnerVideo)(options.runnerJob, this.lTags);
            if (!video)
                return;
            const pending = yield video_job_info_1.VideoJobInfoModel.decrease(video.uuid, 'pendingTranscode');
            logger_1.logger.debug(`Pending transcode decreased to ${pending} after cancel`, this.lTags(video.uuid));
            if (pending === 0) {
                logger_1.logger.info(`All transcoding jobs of ${video.uuid} have been processed or canceled, moving it to its next state`, this.lTags(video.uuid));
                const privatePayload = runnerJob.privatePayload;
                yield (0, database_utils_1.retryTransactionWrapper)(video_state_1.moveToNextState, { video, isNewVideo: privatePayload.isNewVideo });
            }
        });
    }
}
exports.AbstractVODTranscodingJobHandler = AbstractVODTranscodingJobHandler;
//# sourceMappingURL=abstract-vod-transcoding-job-handler.js.map