"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadTranscodingRunnerVideo = exports.onVODWebVideoOrAudioMergeTranscodingJob = void 0;
const tslib_1 = require("tslib");
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const logger_1 = require("../../../../helpers/logger");
const ended_transcoding_1 = require("../../../transcoding/ended-transcoding");
const web_transcoding_1 = require("../../../transcoding/web-transcoding");
const video_file_1 = require("../../../video-file");
const video_1 = require("../../../../models/video/video");
function onVODWebVideoOrAudioMergeTranscodingJob(options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { video, videoFilePath, privatePayload } = options;
        const videoFile = yield (0, video_file_1.buildNewFile)({ path: videoFilePath, mode: 'web-video' });
        videoFile.videoId = video.id;
        const newVideoFilePath = (0, path_1.join)((0, path_1.dirname)(videoFilePath), videoFile.filename);
        yield (0, fs_extra_1.move)(videoFilePath, newVideoFilePath);
        yield (0, web_transcoding_1.onWebTorrentVideoFileTranscoding)({
            video,
            videoFile,
            videoOutputPath: newVideoFilePath
        });
        yield (0, ended_transcoding_1.onTranscodingEnded)({ isNewVideo: privatePayload.isNewVideo, moveVideoToNextState: true, video });
    });
}
exports.onVODWebVideoOrAudioMergeTranscodingJob = onVODWebVideoOrAudioMergeTranscodingJob;
function loadTranscodingRunnerVideo(runnerJob, lTags) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const videoUUID = runnerJob.privatePayload.videoUUID;
        const video = yield video_1.VideoModel.loadFull(videoUUID);
        if (!video) {
            logger_1.logger.info('Video %s does not exist anymore after transcoding runner job.', videoUUID, lTags(videoUUID));
            return undefined;
        }
        return video;
    });
}
exports.loadTranscodingRunnerVideo = loadTranscodingRunnerVideo;
//# sourceMappingURL=vod-helpers.js.map