"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VideoStudioTranscodingJobHandler = void 0;
const tslib_1 = require("tslib");
const path_1 = require("path");
const logger_1 = require("../../../helpers/logger");
const video_studio_1 = require("../../video-studio");
const extra_utils_1 = require("../../../../shared/extra-utils");
const models_1 = require("../../../../shared/models");
const runner_urls_1 = require("../runner-urls");
const abstract_job_handler_1 = require("./abstract-job-handler");
const shared_1 = require("./shared");
class VideoStudioTranscodingJobHandler extends abstract_job_handler_1.AbstractJobHandler {
    create(options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { video, priority, tasks } = options;
            const jobUUID = (0, extra_utils_1.buildUUID)();
            const payload = {
                input: {
                    videoFileUrl: (0, runner_urls_1.generateRunnerTranscodingVideoInputFileUrl)(jobUUID, video.uuid)
                },
                tasks: tasks.map(t => {
                    if ((0, models_1.isVideoStudioTaskIntro)(t) || (0, models_1.isVideoStudioTaskOutro)(t)) {
                        return Object.assign(Object.assign({}, t), { options: Object.assign(Object.assign({}, t.options), { file: (0, runner_urls_1.generateRunnerEditionTranscodingVideoInputFileUrl)(jobUUID, video.uuid, (0, path_1.basename)(t.options.file)) }) });
                    }
                    if ((0, models_1.isVideoStudioTaskWatermark)(t)) {
                        return Object.assign(Object.assign({}, t), { options: Object.assign(Object.assign({}, t.options), { file: (0, runner_urls_1.generateRunnerEditionTranscodingVideoInputFileUrl)(jobUUID, video.uuid, (0, path_1.basename)(t.options.file)) }) });
                    }
                    return t;
                })
            };
            const privatePayload = {
                videoUUID: video.uuid,
                originalTasks: tasks
            };
            const job = yield this.createRunnerJob({
                type: 'video-studio-transcoding',
                jobUUID,
                payload,
                privatePayload,
                priority
            });
            return job;
        });
    }
    isAbortSupported() {
        return true;
    }
    specificUpdate(_options) {
    }
    specificAbort(_options) {
    }
    specificComplete(options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { runnerJob, resultPayload } = options;
            const privatePayload = runnerJob.privatePayload;
            const video = yield (0, shared_1.loadTranscodingRunnerVideo)(runnerJob, this.lTags);
            if (!video) {
                yield (0, video_studio_1.safeCleanupStudioTMPFiles)(privatePayload.originalTasks);
            }
            const videoFilePath = resultPayload.videoFile;
            yield (0, video_studio_1.onVideoStudioEnded)({ video, editionResultPath: videoFilePath, tasks: privatePayload.originalTasks });
            logger_1.logger.info('Runner video edition transcoding job %s for %s ended.', runnerJob.uuid, video.uuid, this.lTags(video.uuid, runnerJob.uuid));
        });
    }
    specificError(options) {
        if (options.nextState === models_1.RunnerJobState.ERRORED) {
            return this.specificErrorOrCancel(options);
        }
        return Promise.resolve();
    }
    specificCancel(options) {
        return this.specificErrorOrCancel(options);
    }
    specificErrorOrCancel(options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { runnerJob } = options;
            const payload = runnerJob.privatePayload;
            yield (0, video_studio_1.safeCleanupStudioTMPFiles)(payload.originalTasks);
            const video = yield (0, shared_1.loadTranscodingRunnerVideo)(options.runnerJob, this.lTags);
            if (!video)
                return;
            return video.setNewState(1, false, undefined);
        });
    }
}
exports.VideoStudioTranscodingJobHandler = VideoStudioTranscodingJobHandler;
//# sourceMappingURL=video-studio-transcoding-job-handler.js.map