"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VODAudioMergeTranscodingJobHandler = void 0;
const tslib_1 = require("tslib");
const lodash_1 = require("lodash");
const logger_1 = require("../../../helpers/logger");
const video_job_info_1 = require("../../../models/video/video-job-info");
const extra_utils_1 = require("../../../../shared/extra-utils");
const ffmpeg_1 = require("../../../../shared/ffmpeg");
const runner_urls_1 = require("../runner-urls");
const abstract_vod_transcoding_job_handler_1 = require("./abstract-vod-transcoding-job-handler");
const shared_1 = require("./shared");
class VODAudioMergeTranscodingJobHandler extends abstract_vod_transcoding_job_handler_1.AbstractVODTranscodingJobHandler {
    create(options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { video, resolution, fps, priority, dependsOnRunnerJob } = options;
            const jobUUID = (0, extra_utils_1.buildUUID)();
            const payload = {
                input: {
                    audioFileUrl: (0, runner_urls_1.generateRunnerTranscodingVideoInputFileUrl)(jobUUID, video.uuid),
                    previewFileUrl: (0, runner_urls_1.generateRunnerTranscodingVideoPreviewFileUrl)(jobUUID, video.uuid)
                },
                output: {
                    resolution,
                    fps
                }
            };
            const privatePayload = Object.assign(Object.assign({}, (0, lodash_1.pick)(options, ['isNewVideo'])), { videoUUID: video.uuid });
            const job = yield this.createRunnerJob({
                type: 'vod-audio-merge-transcoding',
                jobUUID,
                payload,
                privatePayload,
                priority,
                dependsOnRunnerJob
            });
            yield video_job_info_1.VideoJobInfoModel.increaseOrCreate(video.uuid, 'pendingTranscode');
            return job;
        });
    }
    specificComplete(options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { runnerJob, resultPayload } = options;
            const privatePayload = runnerJob.privatePayload;
            const video = yield (0, shared_1.loadTranscodingRunnerVideo)(runnerJob, this.lTags);
            if (!video)
                return;
            const videoFilePath = resultPayload.videoFile;
            video.duration = yield (0, ffmpeg_1.getVideoStreamDuration)(videoFilePath);
            yield video.save();
            const oldAudioFile = video.VideoFiles[0];
            yield video.removeWebTorrentFile(oldAudioFile);
            yield oldAudioFile.destroy();
            video.VideoFiles = [];
            yield (0, shared_1.onVODWebVideoOrAudioMergeTranscodingJob)({ video, videoFilePath, privatePayload });
            logger_1.logger.info('Runner VOD audio merge transcoding job %s for %s ended.', runnerJob.uuid, video.uuid, this.lTags(video.uuid, runnerJob.uuid));
        });
    }
}
exports.VODAudioMergeTranscodingJobHandler = VODAudioMergeTranscodingJobHandler;
//# sourceMappingURL=vod-audio-merge-transcoding-job-handler.js.map