"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VODHLSTranscodingJobHandler = void 0;
const tslib_1 = require("tslib");
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const logger_1 = require("../../../helpers/logger");
const hls_1 = require("../../hls");
const paths_1 = require("../../paths");
const ended_transcoding_1 = require("../../transcoding/ended-transcoding");
const hls_transcoding_1 = require("../../transcoding/hls-transcoding");
const video_file_1 = require("../../video-file");
const video_job_info_1 = require("../../../models/video/video-job-info");
const core_utils_1 = require("../../../../shared/core-utils");
const extra_utils_1 = require("../../../../shared/extra-utils");
const runner_urls_1 = require("../runner-urls");
const abstract_vod_transcoding_job_handler_1 = require("./abstract-vod-transcoding-job-handler");
const shared_1 = require("./shared");
class VODHLSTranscodingJobHandler extends abstract_vod_transcoding_job_handler_1.AbstractVODTranscodingJobHandler {
    create(options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { video, resolution, fps, dependsOnRunnerJob, priority } = options;
            const jobUUID = (0, extra_utils_1.buildUUID)();
            const payload = {
                input: {
                    videoFileUrl: (0, runner_urls_1.generateRunnerTranscodingVideoInputFileUrl)(jobUUID, video.uuid)
                },
                output: {
                    resolution,
                    fps
                }
            };
            const privatePayload = Object.assign(Object.assign({}, (0, core_utils_1.pick)(options, ['isNewVideo', 'deleteWebVideoFiles'])), { videoUUID: video.uuid });
            const job = yield this.createRunnerJob({
                type: 'vod-hls-transcoding',
                jobUUID,
                payload,
                privatePayload,
                priority,
                dependsOnRunnerJob
            });
            yield video_job_info_1.VideoJobInfoModel.increaseOrCreate(video.uuid, 'pendingTranscode');
            return job;
        });
    }
    specificComplete(options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { runnerJob, resultPayload } = options;
            const privatePayload = runnerJob.privatePayload;
            const video = yield (0, shared_1.loadTranscodingRunnerVideo)(runnerJob, this.lTags);
            if (!video)
                return;
            const videoFilePath = resultPayload.videoFile;
            const resolutionPlaylistFilePath = resultPayload.resolutionPlaylistFile;
            const videoFile = yield (0, video_file_1.buildNewFile)({ path: videoFilePath, mode: 'hls' });
            const newVideoFilePath = (0, path_1.join)((0, path_1.dirname)(videoFilePath), videoFile.filename);
            yield (0, fs_extra_1.move)(videoFilePath, newVideoFilePath);
            const resolutionPlaylistFilename = (0, paths_1.getHlsResolutionPlaylistFilename)(videoFile.filename);
            const newResolutionPlaylistFilePath = (0, path_1.join)((0, path_1.dirname)(resolutionPlaylistFilePath), resolutionPlaylistFilename);
            yield (0, fs_extra_1.move)(resolutionPlaylistFilePath, newResolutionPlaylistFilePath);
            yield (0, hls_1.renameVideoFileInPlaylist)(newResolutionPlaylistFilePath, videoFile.filename);
            yield (0, hls_transcoding_1.onHLSVideoFileTranscoding)({
                video,
                videoFile,
                m3u8OutputPath: newResolutionPlaylistFilePath,
                videoOutputPath: newVideoFilePath
            });
            yield (0, ended_transcoding_1.onTranscodingEnded)({ isNewVideo: privatePayload.isNewVideo, moveVideoToNextState: true, video });
            if (privatePayload.deleteWebVideoFiles === true) {
                logger_1.logger.info('Removing web video files of %s now we have a HLS version of it.', video.uuid, this.lTags(video.uuid));
                yield (0, video_file_1.removeAllWebTorrentFiles)(video);
            }
            logger_1.logger.info('Runner VOD HLS job %s for %s ended.', runnerJob.uuid, video.uuid, this.lTags(runnerJob.uuid, video.uuid));
        });
    }
}
exports.VODHLSTranscodingJobHandler = VODHLSTranscodingJobHandler;
//# sourceMappingURL=vod-hls-transcoding-job-handler.js.map