"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateLastRunnerContact = void 0;
const tslib_1 = require("tslib");
const database_utils_1 = require("../../helpers/database-utils");
const logger_1 = require("../../helpers/logger");
const database_1 = require("../../initializers/database");
const constants_1 = require("../../initializers/constants");
const lTags = (0, logger_1.loggerTagsFactory)('runner');
const updatingRunner = new Set();
function updateLastRunnerContact(req, runner) {
    const now = new Date();
    if (now.getTime() - runner.lastContact.getTime() < constants_1.RUNNER_JOBS.LAST_CONTACT_UPDATE_INTERVAL)
        return;
    if (updatingRunner.has(runner.id))
        return;
    updatingRunner.add(runner.id);
    runner.lastContact = now;
    runner.ip = req.ip;
    logger_1.logger.debug('Updating last runner contact for %s', runner.name, lTags(runner.name));
    (0, database_utils_1.retryTransactionWrapper)(() => {
        return database_1.sequelizeTypescript.transaction((transaction) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            return runner.save({ transaction });
        }));
    })
        .catch(err => logger_1.logger.error('Cannot update last runner contact for %s', runner.name, Object.assign({ err }, lTags(runner.name))))
        .finally(() => updatingRunner.delete(runner.id));
}
exports.updateLastRunnerContact = updateLastRunnerContact;
//# sourceMappingURL=runner.js.map