"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RunnerJobWatchDogScheduler = void 0;
const tslib_1 = require("tslib");
const config_1 = require("../../initializers/config");
const runner_job_1 = require("../../models/runner/runner-job");
const logger_1 = require("../../helpers/logger");
const constants_1 = require("../../initializers/constants");
const runners_1 = require("../runners");
const abstract_scheduler_1 = require("./abstract-scheduler");
const lTags = (0, logger_1.loggerTagsFactory)('runner');
class RunnerJobWatchDogScheduler extends abstract_scheduler_1.AbstractScheduler {
    constructor() {
        super();
        this.schedulerIntervalMs = constants_1.SCHEDULER_INTERVALS_MS.RUNNER_JOB_WATCH_DOG;
    }
    internalExecute() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const vodStalledJobs = yield runner_job_1.RunnerJobModel.listStalledJobs({
                staleTimeMS: config_1.CONFIG.REMOTE_RUNNERS.STALLED_JOBS.VOD,
                types: ['vod-audio-merge-transcoding', 'vod-hls-transcoding', 'vod-web-video-transcoding']
            });
            const liveStalledJobs = yield runner_job_1.RunnerJobModel.listStalledJobs({
                staleTimeMS: config_1.CONFIG.REMOTE_RUNNERS.STALLED_JOBS.LIVE,
                types: ['live-rtmp-hls-transcoding']
            });
            for (const stalled of [...vodStalledJobs, ...liveStalledJobs]) {
                logger_1.logger.info('Abort stalled runner job %s (%s)', stalled.uuid, stalled.type, lTags(stalled.uuid, stalled.type));
                const Handler = (0, runners_1.getRunnerJobHandlerClass)(stalled);
                yield new Handler().abort({ runnerJob: stalled });
            }
        });
    }
    static get Instance() {
        return this.instance || (this.instance = new this());
    }
}
exports.RunnerJobWatchDogScheduler = RunnerJobWatchDogScheduler;
//# sourceMappingURL=runner-job-watch-dog-scheduler.js.map