"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.computeResolutionsToTranscode = exports.buildOriginalFileResolution = void 0;
const config_1 = require("../../initializers/config");
const core_utils_1 = require("../../../shared/core-utils");
function buildOriginalFileResolution(inputResolution) {
    if (config_1.CONFIG.TRANSCODING.ALWAYS_TRANSCODE_ORIGINAL_RESOLUTION === true) {
        return (0, core_utils_1.toEven)(inputResolution);
    }
    const resolutions = computeResolutionsToTranscode({
        input: inputResolution,
        type: 'vod',
        includeInput: false,
        strictLower: false,
        hasAudio: true
    });
    if (resolutions.length === 0) {
        return (0, core_utils_1.toEven)(inputResolution);
    }
    return Math.max(...resolutions);
}
exports.buildOriginalFileResolution = buildOriginalFileResolution;
function computeResolutionsToTranscode(options) {
    const { input, type, includeInput, strictLower, hasAudio } = options;
    const configResolutions = type === 'vod'
        ? config_1.CONFIG.TRANSCODING.RESOLUTIONS
        : config_1.CONFIG.LIVE.TRANSCODING.RESOLUTIONS;
    const resolutionsEnabled = new Set();
    const availableResolutions = [
        0,
        480,
        360,
        720,
        240,
        144,
        1080,
        1440,
        2160
    ];
    for (const resolution of availableResolutions) {
        if (configResolutions[resolution + 'p'] !== true)
            continue;
        if (input < resolution)
            continue;
        if (strictLower && input === resolution)
            continue;
        if (resolution === 0 && !hasAudio)
            continue;
        resolutionsEnabled.add(resolution);
    }
    if (includeInput) {
        resolutionsEnabled.add((0, core_utils_1.toEven)(input));
    }
    return Array.from(resolutionsEnabled);
}
exports.computeResolutionsToTranscode = computeResolutionsToTranscode;
//# sourceMappingURL=transcoding-resolutions.js.map