"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.onWebTorrentVideoFileTranscoding = exports.mergeAudioVideofile = exports.transcodeNewWebTorrentResolution = exports.optimizeOriginalVideofile = void 0;
const tslib_1 = require("tslib");
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const ffmpeg_1 = require("../../helpers/ffmpeg");
const webtorrent_1 = require("../../helpers/webtorrent");
const video_1 = require("../../models/video/video");
const ffmpeg_2 = require("../../../shared/ffmpeg");
const config_1 = require("../../initializers/config");
const video_file_1 = require("../../models/video/video-file");
const paths_1 = require("../paths");
const video_file_2 = require("../video-file");
const video_path_manager_1 = require("../video-path-manager");
const shared_1 = require("./shared");
const transcoding_resolutions_1 = require("./transcoding-resolutions");
function optimizeOriginalVideofile(options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { video, inputVideoFile, quickTranscode, job } = options;
        const transcodeDirectory = config_1.CONFIG.STORAGE.TMP_DIR;
        const newExtname = '.mp4';
        const inputFileMutexReleaser = yield video_path_manager_1.VideoPathManager.Instance.lockFiles(video.uuid);
        try {
            yield video.reload();
            yield inputVideoFile.reload();
            const fileWithVideoOrPlaylist = inputVideoFile.withVideoOrPlaylist(video);
            const result = yield video_path_manager_1.VideoPathManager.Instance.makeAvailableVideoFile(fileWithVideoOrPlaylist, (videoInputPath) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                const videoOutputPath = (0, path_1.join)(transcodeDirectory, video.id + '-transcoded' + newExtname);
                const transcodeType = quickTranscode
                    ? 'quick-transcode'
                    : 'video';
                const resolution = (0, transcoding_resolutions_1.buildOriginalFileResolution)(inputVideoFile.resolution);
                const fps = (0, ffmpeg_1.computeOutputFPS)({ inputFPS: inputVideoFile.fps, resolution });
                yield (0, shared_1.buildFFmpegVOD)(job).transcode({
                    type: transcodeType,
                    inputPath: videoInputPath,
                    outputPath: videoOutputPath,
                    inputFileMutexReleaser,
                    resolution,
                    fps
                });
                inputVideoFile.resolution = resolution;
                inputVideoFile.extname = newExtname;
                inputVideoFile.filename = (0, paths_1.generateWebTorrentVideoFilename)(resolution, newExtname);
                inputVideoFile.storage = 0;
                const { videoFile } = yield onWebTorrentVideoFileTranscoding({
                    video,
                    videoFile: inputVideoFile,
                    videoOutputPath
                });
                yield (0, fs_extra_1.remove)(videoInputPath);
                return { transcodeType, videoFile };
            }));
            return result;
        }
        finally {
            inputFileMutexReleaser();
        }
    });
}
exports.optimizeOriginalVideofile = optimizeOriginalVideofile;
function transcodeNewWebTorrentResolution(options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { video: videoArg, resolution, fps, job } = options;
        const transcodeDirectory = config_1.CONFIG.STORAGE.TMP_DIR;
        const newExtname = '.mp4';
        const inputFileMutexReleaser = yield video_path_manager_1.VideoPathManager.Instance.lockFiles(videoArg.uuid);
        try {
            const video = yield video_1.VideoModel.loadFull(videoArg.uuid);
            const file = video.getMaxQualityFile().withVideoOrPlaylist(video);
            const result = yield video_path_manager_1.VideoPathManager.Instance.makeAvailableVideoFile(file, (videoInputPath) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                const newVideoFile = new video_file_1.VideoFileModel({
                    resolution,
                    extname: newExtname,
                    filename: (0, paths_1.generateWebTorrentVideoFilename)(resolution, newExtname),
                    size: 0,
                    videoId: video.id
                });
                const videoOutputPath = (0, path_1.join)(transcodeDirectory, newVideoFile.filename);
                const transcodeOptions = {
                    type: 'video',
                    inputPath: videoInputPath,
                    outputPath: videoOutputPath,
                    inputFileMutexReleaser,
                    resolution,
                    fps
                };
                yield (0, shared_1.buildFFmpegVOD)(job).transcode(transcodeOptions);
                return onWebTorrentVideoFileTranscoding({ video, videoFile: newVideoFile, videoOutputPath });
            }));
            return result;
        }
        finally {
            inputFileMutexReleaser();
        }
    });
}
exports.transcodeNewWebTorrentResolution = transcodeNewWebTorrentResolution;
function mergeAudioVideofile(options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { video: videoArg, resolution, fps, job } = options;
        const transcodeDirectory = config_1.CONFIG.STORAGE.TMP_DIR;
        const newExtname = '.mp4';
        const inputFileMutexReleaser = yield video_path_manager_1.VideoPathManager.Instance.lockFiles(videoArg.uuid);
        try {
            const video = yield video_1.VideoModel.loadFull(videoArg.uuid);
            const inputVideoFile = video.getMinQualityFile();
            const fileWithVideoOrPlaylist = inputVideoFile.withVideoOrPlaylist(video);
            const result = yield video_path_manager_1.VideoPathManager.Instance.makeAvailableVideoFile(fileWithVideoOrPlaylist, (audioInputPath) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                const videoOutputPath = (0, path_1.join)(transcodeDirectory, video.id + '-transcoded' + newExtname);
                const previewPath = video.getPreview().getPath();
                const tmpPreviewPath = (0, path_1.join)(config_1.CONFIG.STORAGE.TMP_DIR, (0, path_1.basename)(previewPath));
                yield (0, fs_extra_1.copyFile)(previewPath, tmpPreviewPath);
                const transcodeOptions = {
                    type: 'merge-audio',
                    inputPath: tmpPreviewPath,
                    outputPath: videoOutputPath,
                    inputFileMutexReleaser,
                    audioPath: audioInputPath,
                    resolution,
                    fps
                };
                try {
                    yield (0, shared_1.buildFFmpegVOD)(job).transcode(transcodeOptions);
                    yield (0, fs_extra_1.remove)(audioInputPath);
                    yield (0, fs_extra_1.remove)(tmpPreviewPath);
                }
                catch (err) {
                    yield (0, fs_extra_1.remove)(tmpPreviewPath);
                    throw err;
                }
                inputVideoFile.extname = newExtname;
                inputVideoFile.resolution = resolution;
                inputVideoFile.filename = (0, paths_1.generateWebTorrentVideoFilename)(inputVideoFile.resolution, newExtname);
                video.duration = yield (0, ffmpeg_2.getVideoStreamDuration)(videoOutputPath);
                yield video.save();
                return onWebTorrentVideoFileTranscoding({
                    video,
                    videoFile: inputVideoFile,
                    videoOutputPath
                });
            }));
            return result;
        }
        finally {
            inputFileMutexReleaser();
        }
    });
}
exports.mergeAudioVideofile = mergeAudioVideofile;
function onWebTorrentVideoFileTranscoding(options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { video, videoFile, videoOutputPath } = options;
        const mutexReleaser = yield video_path_manager_1.VideoPathManager.Instance.lockFiles(video.uuid);
        try {
            yield video.reload();
            const outputPath = video_path_manager_1.VideoPathManager.Instance.getFSVideoFileOutputPath(video, videoFile);
            const stats = yield (0, fs_extra_1.stat)(videoOutputPath);
            const probe = yield (0, ffmpeg_2.ffprobePromise)(videoOutputPath);
            const fps = yield (0, ffmpeg_2.getVideoStreamFPS)(videoOutputPath, probe);
            const metadata = yield (0, video_file_2.buildFileMetadata)(videoOutputPath, probe);
            yield (0, fs_extra_1.move)(videoOutputPath, outputPath, { overwrite: true });
            videoFile.size = stats.size;
            videoFile.fps = fps;
            videoFile.metadata = metadata;
            yield (0, webtorrent_1.createTorrentAndSetInfoHash)(video, videoFile);
            const oldFile = yield video_file_1.VideoFileModel.loadWebTorrentFile({ videoId: video.id, fps: videoFile.fps, resolution: videoFile.resolution });
            if (oldFile)
                yield video.removeWebTorrentFile(oldFile);
            yield video_file_1.VideoFileModel.customUpsert(videoFile, 'video', undefined);
            video.VideoFiles = yield video.$get('VideoFiles');
            return { video, videoFile };
        }
        finally {
            mutexReleaser();
        }
    });
}
exports.onWebTorrentVideoFileTranscoding = onWebTorrentVideoFileTranscoding;
//# sourceMappingURL=web-transcoding.js.map