"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VideoTokensManager = void 0;
const lru_cache_1 = require("lru-cache");
const constants_1 = require("../initializers/constants");
const core_utils_1 = require("../../shared/core-utils");
const extra_utils_1 = require("../../shared/extra-utils");
class VideoTokensManager {
    constructor() {
        this.lruCache = new lru_cache_1.LRUCache({
            max: constants_1.LRU_CACHE.VIDEO_TOKENS.MAX_SIZE,
            ttl: constants_1.LRU_CACHE.VIDEO_TOKENS.TTL
        });
    }
    create(options) {
        const token = (0, extra_utils_1.buildUUID)();
        const expires = new Date(new Date().getTime() + constants_1.LRU_CACHE.VIDEO_TOKENS.TTL);
        this.lruCache.set(token, (0, core_utils_1.pick)(options, ['user', 'videoUUID']));
        return { token, expires };
    }
    hasToken(options) {
        const value = this.lruCache.get(options.token);
        if (!value)
            return false;
        return value.videoUUID === options.videoUUID;
    }
    getUserFromToken(options) {
        const value = this.lruCache.get(options.token);
        if (!value)
            return undefined;
        return value.user;
    }
    static get Instance() {
        return this.instance || (this.instance = new this());
    }
}
exports.VideoTokensManager = VideoTokensManager;
//# sourceMappingURL=video-tokens-manager.js.map