"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.apiRateLimiter = exports.buildRateLimiter = void 0;
const tslib_1 = require("tslib");
const express_rate_limit_1 = tslib_1.__importDefault(require("express-rate-limit"));
const config_1 = require("../initializers/config");
const runner_1 = require("../models/runner/runner");
const auth_1 = require("./auth");
const whitelistRoles = new Set([0, 1]);
function buildRateLimiter(options) {
    return (0, express_rate_limit_1.default)({
        windowMs: options.windowMs,
        max: options.max,
        skipFailedRequests: options.skipFailedRequests,
        handler: (req, res, next, options) => {
            var _a;
            if ((_a = req.body) === null || _a === void 0 ? void 0 : _a.runnerToken) {
                return runner_1.RunnerModel.loadByToken(req.body.runnerToken)
                    .then(runner => {
                    if (runner)
                        return next();
                    return sendRateLimited(res, options);
                });
            }
            return (0, auth_1.optionalAuthenticate)(req, res, () => {
                if (res.locals.authenticated === true && whitelistRoles.has(res.locals.oauth.token.User.role)) {
                    return next();
                }
                return sendRateLimited(res, options);
            });
        }
    });
}
exports.buildRateLimiter = buildRateLimiter;
exports.apiRateLimiter = buildRateLimiter({
    windowMs: config_1.CONFIG.RATES_LIMIT.API.WINDOW_MS,
    max: config_1.CONFIG.RATES_LIMIT.API.MAX
});
function sendRateLimited(res, options) {
    return res.status(options.statusCode).send(options.message);
}
//# sourceMappingURL=rate-limiter.js.map