"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runnerJobGetVideoStudioTaskFileValidator = exports.runnerJobGetVideoTranscodingFileValidator = void 0;
const tslib_1 = require("tslib");
const express_validator_1 = require("express-validator");
const path_1 = require("path");
const misc_1 = require("../../../helpers/custom-validators/misc");
const models_1 = require("../../../../shared/models");
const shared_1 = require("../shared");
const tags = ['runner'];
exports.runnerJobGetVideoTranscodingFileValidator = [
    (0, shared_1.isValidVideoIdParam)('videoId'),
    (req, res, next) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        if ((0, shared_1.areValidationErrors)(req, res))
            return;
        if (!(yield (0, shared_1.doesVideoExist)(req.params.videoId, res, 'all')))
            return;
        const runnerJob = res.locals.runnerJob;
        if (runnerJob.privatePayload.videoUUID !== res.locals.videoAll.uuid) {
            return res.fail({
                status: 403,
                message: 'Job is not associated to this video',
                tags: [...tags, res.locals.videoAll.uuid]
            });
        }
        return next();
    })
];
exports.runnerJobGetVideoStudioTaskFileValidator = [
    (0, express_validator_1.param)('filename').custom(v => (0, misc_1.isSafeFilename)(v)),
    (req, res, next) => {
        if ((0, shared_1.areValidationErrors)(req, res))
            return;
        const filename = req.params.filename;
        const payload = res.locals.runnerJob.payload;
        const found = Array.isArray(payload === null || payload === void 0 ? void 0 : payload.tasks) && payload.tasks.some(t => {
            if ((0, models_1.hasVideoStudioTaskFile)(t)) {
                return (0, path_1.basename)(t.options.file) === filename;
            }
            return false;
        });
        if (!found) {
            return res.fail({
                status: 400,
                message: 'File is not associated to this edition task',
                tags: [...tags, res.locals.videoAll.uuid]
            });
        }
        return next();
    }
];
//# sourceMappingURL=job-files.js.map