"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRunnerFromTokenValidator = exports.deleteRunnerValidator = exports.registerRunnerValidator = void 0;
const tslib_1 = require("tslib");
const express_validator_1 = require("express-validator");
const misc_1 = require("../../../helpers/custom-validators/misc");
const runners_1 = require("../../../helpers/custom-validators/runners/runners");
const runner_1 = require("../../../models/runner/runner");
const runner_registration_token_1 = require("../../../models/runner/runner-registration-token");
const core_utils_1 = require("../../../../shared/core-utils");
const utils_1 = require("../shared/utils");
const tags = ['runner'];
const registerRunnerValidator = [
    (0, express_validator_1.body)('registrationToken').custom(runners_1.isRunnerRegistrationTokenValid),
    (0, express_validator_1.body)('name').custom(runners_1.isRunnerNameValid),
    (0, express_validator_1.body)('description').optional().custom(runners_1.isRunnerDescriptionValid),
    (req, res, next) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        if ((0, utils_1.areValidationErrors)(req, res, { tags }))
            return;
        const body = req.body;
        const runnerRegistrationToken = yield runner_registration_token_1.RunnerRegistrationTokenModel.loadByRegistrationToken(body.registrationToken);
        if (!runnerRegistrationToken) {
            return res.fail({
                status: 404,
                message: 'Registration token is invalid',
                tags
            });
        }
        res.locals.runnerRegistrationToken = runnerRegistrationToken;
        return next();
    })
];
exports.registerRunnerValidator = registerRunnerValidator;
const deleteRunnerValidator = [
    (0, express_validator_1.param)('runnerId').custom(misc_1.isIdValid),
    (req, res, next) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        if ((0, utils_1.areValidationErrors)(req, res, { tags }))
            return;
        const runner = yield runner_1.RunnerModel.load((0, core_utils_1.forceNumber)(req.params.runnerId));
        if (!runner) {
            return res.fail({
                status: 404,
                message: 'Runner not found',
                tags
            });
        }
        res.locals.runner = runner;
        return next();
    })
];
exports.deleteRunnerValidator = deleteRunnerValidator;
const getRunnerFromTokenValidator = [
    (0, express_validator_1.body)('runnerToken').custom(runners_1.isRunnerTokenValid),
    (req, res, next) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        if ((0, utils_1.areValidationErrors)(req, res, { tags }))
            return;
        const runner = yield runner_1.RunnerModel.loadByToken(req.body.runnerToken);
        if (!runner) {
            return res.fail({
                status: 404,
                message: 'Unknown runner token',
                type: "unknown_runner_token",
                tags
            });
        }
        res.locals.runner = runner;
        return next();
    })
];
exports.getRunnerFromTokenValidator = getRunnerFromTokenValidator;
//# sourceMappingURL=runners.js.map