"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkRegistrationExist = exports.checkRegistrationHandlesDoNotAlreadyExist = exports.checkRegistrationEmailExist = exports.checkRegistrationIdExist = void 0;
const tslib_1 = require("tslib");
const user_registration_1 = require("../../../models/user/user-registration");
const core_utils_1 = require("../../../../shared/core-utils");
function checkRegistrationIdExist(idArg, res) {
    const id = (0, core_utils_1.forceNumber)(idArg);
    return checkRegistrationExist(() => user_registration_1.UserRegistrationModel.load(id), res);
}
exports.checkRegistrationIdExist = checkRegistrationIdExist;
function checkRegistrationEmailExist(email, res, abortResponse = true) {
    return checkRegistrationExist(() => user_registration_1.UserRegistrationModel.loadByEmail(email), res, abortResponse);
}
exports.checkRegistrationEmailExist = checkRegistrationEmailExist;
function checkRegistrationHandlesDoNotAlreadyExist(options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { res } = options;
        const registration = yield user_registration_1.UserRegistrationModel.loadByEmailOrHandle((0, core_utils_1.pick)(options, ['username', 'email', 'channelHandle']));
        if (registration) {
            res.fail({
                status: 409,
                message: 'Registration with this username, channel name or email already exists.'
            });
            return false;
        }
        return true;
    });
}
exports.checkRegistrationHandlesDoNotAlreadyExist = checkRegistrationHandlesDoNotAlreadyExist;
function checkRegistrationExist(finder, res, abortResponse = true) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const registration = yield finder();
        if (!registration) {
            if (abortResponse === true) {
                res.fail({
                    status: 404,
                    message: 'User not found'
                });
            }
            return false;
        }
        res.locals.userRegistration = registration;
        return true;
    });
}
exports.checkRegistrationExist = checkRegistrationExist;
//# sourceMappingURL=user-registrations.js.map