"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.registrationVerifyEmailValidator = exports.usersVerifyEmailValidator = exports.usersAskSendVerifyEmailValidator = void 0;
const tslib_1 = require("tslib");
const express_validator_1 = require("express-validator");
const misc_1 = require("../../helpers/custom-validators/misc");
const logger_1 = require("../../helpers/logger");
const redis_1 = require("../../lib/redis");
const shared_1 = require("./shared");
const user_registrations_1 = require("./shared/user-registrations");
const usersAskSendVerifyEmailValidator = [
    (0, express_validator_1.body)('email').isEmail().not().isEmpty().withMessage('Should have a valid email'),
    (req, res, next) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        var _a;
        if ((0, shared_1.areValidationErrors)(req, res))
            return;
        const [userExists, registrationExists] = yield Promise.all([
            (0, shared_1.checkUserEmailExist)(req.body.email, res, false),
            (0, user_registrations_1.checkRegistrationEmailExist)(req.body.email, res, false)
        ]);
        if (!userExists && !registrationExists) {
            logger_1.logger.debug('User or registration with email %s does not exist (asking verify email).', req.body.email);
            return res.status(204).end();
        }
        if ((_a = res.locals.user) === null || _a === void 0 ? void 0 : _a.pluginAuth) {
            return res.fail({
                status: 409,
                message: 'Cannot ask verification email of a user that uses a plugin authentication.'
            });
        }
        return next();
    })
];
exports.usersAskSendVerifyEmailValidator = usersAskSendVerifyEmailValidator;
const usersVerifyEmailValidator = [
    (0, express_validator_1.param)('id')
        .isInt().not().isEmpty().withMessage('Should have a valid id'),
    (0, express_validator_1.body)('verificationString')
        .not().isEmpty().withMessage('Should have a valid verification string'),
    (0, express_validator_1.body)('isPendingEmail')
        .optional()
        .customSanitizer(misc_1.toBooleanOrNull),
    (req, res, next) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        if ((0, shared_1.areValidationErrors)(req, res))
            return;
        if (!(yield (0, shared_1.checkUserIdExist)(req.params.id, res)))
            return;
        const user = res.locals.user;
        const redisVerificationString = yield redis_1.Redis.Instance.getUserVerifyEmailLink(user.id);
        if (redisVerificationString !== req.body.verificationString) {
            return res.fail({ status: 403, message: 'Invalid verification string.' });
        }
        return next();
    })
];
exports.usersVerifyEmailValidator = usersVerifyEmailValidator;
const registrationVerifyEmailValidator = [
    (0, express_validator_1.param)('registrationId')
        .isInt().not().isEmpty().withMessage('Should have a valid registrationId'),
    (0, express_validator_1.body)('verificationString')
        .not().isEmpty().withMessage('Should have a valid verification string'),
    (req, res, next) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        if ((0, shared_1.areValidationErrors)(req, res))
            return;
        if (!(yield (0, user_registrations_1.checkRegistrationIdExist)(req.params.registrationId, res)))
            return;
        const registration = res.locals.userRegistration;
        const redisVerificationString = yield redis_1.Redis.Instance.getRegistrationVerifyEmailLink(registration.id);
        if (redisVerificationString !== req.body.verificationString) {
            return res.fail({ status: 403, message: 'Invalid verification string.' });
        }
        return next();
    })
];
exports.registrationVerifyEmailValidator = registrationVerifyEmailValidator;
//# sourceMappingURL=user-email-verification.js.map