"use strict";
var RunnerRegistrationTokenModel_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.RunnerRegistrationTokenModel = void 0;
const tslib_1 = require("tslib");
const sequelize_1 = require("sequelize");
const sequelize_typescript_1 = require("sequelize-typescript");
const shared_1 = require("../shared");
const runner_1 = require("./runner");
let RunnerRegistrationTokenModel = RunnerRegistrationTokenModel_1 = class RunnerRegistrationTokenModel extends sequelize_typescript_1.Model {
    static load(id) {
        return RunnerRegistrationTokenModel_1.findByPk(id);
    }
    static loadByRegistrationToken(registrationToken) {
        const query = {
            where: { registrationToken }
        };
        return RunnerRegistrationTokenModel_1.findOne(query);
    }
    static countTotal() {
        return RunnerRegistrationTokenModel_1.unscoped().count();
    }
    static listForApi(options) {
        const { start, count, sort } = options;
        const query = {
            attributes: {
                include: [
                    [
                        (0, sequelize_1.literal)('(SELECT COUNT(*) FROM "runner" WHERE "runner"."runnerRegistrationTokenId" = "RunnerRegistrationTokenModel"."id")'),
                        'registeredRunnersCount'
                    ]
                ]
            },
            offset: start,
            limit: count,
            order: (0, shared_1.getSort)(sort)
        };
        return Promise.all([
            RunnerRegistrationTokenModel_1.count(query),
            RunnerRegistrationTokenModel_1.findAll(query)
        ]).then(([total, data]) => ({ total, data }));
    }
    toFormattedJSON() {
        const registeredRunnersCount = this.get('registeredRunnersCount');
        return {
            id: this.id,
            registrationToken: this.registrationToken,
            createdAt: this.createdAt,
            updatedAt: this.updatedAt,
            registeredRunnersCount
        };
    }
};
tslib_1.__decorate([
    (0, sequelize_typescript_1.AllowNull)(false),
    sequelize_typescript_1.Column,
    tslib_1.__metadata("design:type", String)
], RunnerRegistrationTokenModel.prototype, "registrationToken", void 0);
tslib_1.__decorate([
    sequelize_typescript_1.CreatedAt,
    tslib_1.__metadata("design:type", Date)
], RunnerRegistrationTokenModel.prototype, "createdAt", void 0);
tslib_1.__decorate([
    sequelize_typescript_1.UpdatedAt,
    tslib_1.__metadata("design:type", Date)
], RunnerRegistrationTokenModel.prototype, "updatedAt", void 0);
tslib_1.__decorate([
    (0, sequelize_typescript_1.HasMany)(() => runner_1.RunnerModel, {
        foreignKey: {
            allowNull: true
        },
        onDelete: 'cascade'
    }),
    tslib_1.__metadata("design:type", Array)
], RunnerRegistrationTokenModel.prototype, "Runners", void 0);
RunnerRegistrationTokenModel = RunnerRegistrationTokenModel_1 = tslib_1.__decorate([
    (0, sequelize_typescript_1.Table)({
        tableName: 'runnerRegistrationToken',
        indexes: [
            {
                fields: ['registrationToken'],
                unique: true
            }
        ]
    })
], RunnerRegistrationTokenModel);
exports.RunnerRegistrationTokenModel = RunnerRegistrationTokenModel;
//# sourceMappingURL=runner-registration-token.js.map