"use strict";
var RunnerModel_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.RunnerModel = void 0;
const tslib_1 = require("tslib");
const sequelize_typescript_1 = require("sequelize-typescript");
const shared_1 = require("../shared");
const runner_registration_token_1 = require("./runner-registration-token");
const constants_1 = require("../../initializers/constants");
let RunnerModel = RunnerModel_1 = class RunnerModel extends sequelize_typescript_1.Model {
    static load(id) {
        return RunnerModel_1.findByPk(id);
    }
    static loadByToken(runnerToken) {
        const query = {
            where: { runnerToken }
        };
        return RunnerModel_1.findOne(query);
    }
    static listForApi(options) {
        const { start, count, sort } = options;
        const query = {
            offset: start,
            limit: count,
            order: (0, shared_1.getSort)(sort)
        };
        return Promise.all([
            RunnerModel_1.count(query),
            RunnerModel_1.findAll(query)
        ]).then(([total, data]) => ({ total, data }));
    }
    toFormattedJSON() {
        return {
            id: this.id,
            name: this.name,
            description: this.description,
            ip: this.ip,
            lastContact: this.lastContact,
            createdAt: this.createdAt,
            updatedAt: this.updatedAt
        };
    }
};
tslib_1.__decorate([
    (0, sequelize_typescript_1.AllowNull)(false),
    sequelize_typescript_1.Column,
    tslib_1.__metadata("design:type", String)
], RunnerModel.prototype, "runnerToken", void 0);
tslib_1.__decorate([
    (0, sequelize_typescript_1.AllowNull)(false),
    sequelize_typescript_1.Column,
    tslib_1.__metadata("design:type", String)
], RunnerModel.prototype, "name", void 0);
tslib_1.__decorate([
    (0, sequelize_typescript_1.AllowNull)(true),
    (0, sequelize_typescript_1.Column)(sequelize_typescript_1.DataType.STRING(constants_1.CONSTRAINTS_FIELDS.RUNNERS.DESCRIPTION.max)),
    tslib_1.__metadata("design:type", String)
], RunnerModel.prototype, "description", void 0);
tslib_1.__decorate([
    (0, sequelize_typescript_1.AllowNull)(false),
    sequelize_typescript_1.Column,
    tslib_1.__metadata("design:type", Date)
], RunnerModel.prototype, "lastContact", void 0);
tslib_1.__decorate([
    (0, sequelize_typescript_1.AllowNull)(false),
    sequelize_typescript_1.Column,
    tslib_1.__metadata("design:type", String)
], RunnerModel.prototype, "ip", void 0);
tslib_1.__decorate([
    sequelize_typescript_1.CreatedAt,
    tslib_1.__metadata("design:type", Date)
], RunnerModel.prototype, "createdAt", void 0);
tslib_1.__decorate([
    sequelize_typescript_1.UpdatedAt,
    tslib_1.__metadata("design:type", Date)
], RunnerModel.prototype, "updatedAt", void 0);
tslib_1.__decorate([
    (0, sequelize_typescript_1.ForeignKey)(() => runner_registration_token_1.RunnerRegistrationTokenModel),
    sequelize_typescript_1.Column,
    tslib_1.__metadata("design:type", Number)
], RunnerModel.prototype, "runnerRegistrationTokenId", void 0);
tslib_1.__decorate([
    (0, sequelize_typescript_1.BelongsTo)(() => runner_registration_token_1.RunnerRegistrationTokenModel, {
        foreignKey: {
            allowNull: false
        },
        onDelete: 'cascade'
    }),
    tslib_1.__metadata("design:type", runner_registration_token_1.RunnerRegistrationTokenModel)
], RunnerModel.prototype, "RunnerRegistrationToken", void 0);
RunnerModel = RunnerModel_1 = tslib_1.__decorate([
    (0, sequelize_typescript_1.Table)({
        tableName: 'runner',
        indexes: [
            {
                fields: ['runnerToken'],
                unique: true
            },
            {
                fields: ['runnerRegistrationTokenId']
            }
        ]
    })
], RunnerModel);
exports.RunnerModel = RunnerModel;
//# sourceMappingURL=runner.js.map