"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.searchAttribute = exports.createSafeIn = exports.parseRowCountResult = exports.parseAggregateResult = exports.buildWhereIdOrUUID = exports.createSimilarityAttribute = exports.doesExist = void 0;
const tslib_1 = require("tslib");
const sequelize_1 = require("sequelize");
const validator_1 = tslib_1.__importDefault(require("validator"));
const core_utils_1 = require("../../../shared/core-utils");
function doesExist(sequelize, query, bind) {
    const options = {
        type: sequelize_1.QueryTypes.SELECT,
        bind,
        raw: true
    };
    return sequelize.query(query, options)
        .then(results => results.length === 1);
}
exports.doesExist = doesExist;
function createSimilarityAttribute(col, value) {
    return sequelize_1.Sequelize.fn('similarity', searchTrigramNormalizeCol(col), searchTrigramNormalizeValue(value));
}
exports.createSimilarityAttribute = createSimilarityAttribute;
function buildWhereIdOrUUID(id) {
    return validator_1.default.isInt('' + id) ? { id } : { uuid: id };
}
exports.buildWhereIdOrUUID = buildWhereIdOrUUID;
function parseAggregateResult(result) {
    if (!result)
        return 0;
    const total = (0, core_utils_1.forceNumber)(result);
    if (isNaN(total))
        return 0;
    return total;
}
exports.parseAggregateResult = parseAggregateResult;
function parseRowCountResult(result) {
    if (result.length !== 0)
        return result[0].total;
    return 0;
}
exports.parseRowCountResult = parseRowCountResult;
function createSafeIn(sequelize, toEscape, additionalUnescaped = []) {
    return toEscape.map(t => {
        return t === null
            ? null
            : sequelize.escape('' + t);
    }).concat(additionalUnescaped).join(', ');
}
exports.createSafeIn = createSafeIn;
function searchAttribute(sourceField, targetField) {
    if (!sourceField)
        return {};
    return {
        [targetField]: {
            [sequelize_1.Op.iLike]: `%${sourceField}%`
        }
    };
}
exports.searchAttribute = searchAttribute;
function searchTrigramNormalizeValue(value) {
    return sequelize_1.Sequelize.fn('lower', sequelize_1.Sequelize.fn('immutable_unaccent', value));
}
function searchTrigramNormalizeCol(col) {
    return sequelize_1.Sequelize.fn('lower', sequelize_1.Sequelize.fn('immutable_unaccent', sequelize_1.Sequelize.col(col)));
}
//# sourceMappingURL=query.js.map