"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getInstanceFollowsSort = exports.getChannelSyncSort = exports.getBlacklistSort = exports.getVideoSort = exports.getAdminUsersSort = exports.getSort = exports.getPlaylistSort = exports.buildSortDirectionAndField = void 0;
const sequelize_1 = require("sequelize");
function getSort(value, lastSort = ['id', 'ASC']) {
    const { direction, field } = buildSortDirectionAndField(value);
    let finalField;
    if (field.toLowerCase() === 'match') {
        finalField = sequelize_1.Sequelize.col('similarity');
    }
    else {
        finalField = field;
    }
    return [[finalField, direction], lastSort];
}
exports.getSort = getSort;
function getAdminUsersSort(value) {
    const { direction, field } = buildSortDirectionAndField(value);
    let finalField;
    if (field === 'videoQuotaUsed') {
        finalField = sequelize_1.Sequelize.col('videoQuotaUsed');
    }
    else {
        finalField = field;
    }
    const nullPolicy = direction === 'ASC'
        ? 'NULLS FIRST'
        : 'NULLS LAST';
    return [[finalField, direction, nullPolicy], ['id', 'ASC']];
}
exports.getAdminUsersSort = getAdminUsersSort;
function getPlaylistSort(value, lastSort = ['id', 'ASC']) {
    const { direction, field } = buildSortDirectionAndField(value);
    if (field.toLowerCase() === 'name') {
        return [['displayName', direction], lastSort];
    }
    return getSort(value, lastSort);
}
exports.getPlaylistSort = getPlaylistSort;
function getVideoSort(value, lastSort = ['id', 'ASC']) {
    const { direction, field } = buildSortDirectionAndField(value);
    if (field.toLowerCase() === 'trending') {
        return [
            [sequelize_1.Sequelize.fn('COALESCE', sequelize_1.Sequelize.fn('SUM', sequelize_1.Sequelize.col('VideoViews.views')), '0'), direction],
            [sequelize_1.Sequelize.col('VideoModel.views'), direction],
            lastSort
        ];
    }
    else if (field === 'publishedAt') {
        return [
            ['ScheduleVideoUpdate', 'updateAt', direction + ' NULLS LAST'],
            [sequelize_1.Sequelize.col('VideoModel.publishedAt'), direction],
            lastSort
        ];
    }
    let finalField;
    if (field.toLowerCase() === 'match') {
        finalField = sequelize_1.Sequelize.col('similarity');
    }
    else {
        finalField = field;
    }
    const firstSort = typeof finalField === 'string'
        ? finalField.split('.').concat([direction])
        : [finalField, direction];
    return [firstSort, lastSort];
}
exports.getVideoSort = getVideoSort;
function getBlacklistSort(value, lastSort = ['id', 'ASC']) {
    const { direction, field } = buildSortDirectionAndField(value);
    const videoFields = new Set(['name', 'duration', 'views', 'likes', 'dislikes', 'uuid']);
    if (videoFields.has(field)) {
        return [
            [(0, sequelize_1.literal)(`"Video.${field}" ${direction}`)],
            lastSort
        ];
    }
    return getSort(value, lastSort);
}
exports.getBlacklistSort = getBlacklistSort;
function getInstanceFollowsSort(value, lastSort = ['id', 'ASC']) {
    const { direction, field } = buildSortDirectionAndField(value);
    if (field === 'redundancyAllowed') {
        return [
            ['ActorFollowing.Server.redundancyAllowed', direction],
            lastSort
        ];
    }
    return getSort(value, lastSort);
}
exports.getInstanceFollowsSort = getInstanceFollowsSort;
function getChannelSyncSort(value) {
    const { direction, field } = buildSortDirectionAndField(value);
    if (field.toLowerCase() === 'videochannel') {
        return [
            [(0, sequelize_1.literal)('"VideoChannel.name"'), direction]
        ];
    }
    return [[field, direction]];
}
exports.getChannelSyncSort = getChannelSyncSort;
function buildSortDirectionAndField(value) {
    let field;
    let direction;
    if (value.substring(0, 1) === '-') {
        direction = 'DESC';
        field = value.substring(1);
    }
    else {
        direction = 'ASC';
        field = value;
    }
    return { direction, field };
}
exports.buildSortDirectionAndField = buildSortDirectionAndField;
//# sourceMappingURL=sort.js.map