"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildLocalActorIdsIn = exports.buildLocalAccountIdsIn = exports.buildServerIdsFollowedBy = exports.buildBlockedAccountSQL = exports.buildSQLAttributes = void 0;
const sequelize_1 = require("sequelize");
const core_utils_1 = require("../../../shared/core-utils");
function buildLocalAccountIdsIn() {
    return (0, sequelize_1.literal)('(SELECT "account"."id" FROM "account" INNER JOIN "actor" ON "actor"."id" = "account"."actorId" AND "actor"."serverId" IS NULL)');
}
exports.buildLocalAccountIdsIn = buildLocalAccountIdsIn;
function buildLocalActorIdsIn() {
    return (0, sequelize_1.literal)('(SELECT "actor"."id" FROM "actor" WHERE "actor"."serverId" IS NULL)');
}
exports.buildLocalActorIdsIn = buildLocalActorIdsIn;
function buildBlockedAccountSQL(blockerIds) {
    const blockerIdsString = blockerIds.join(', ');
    return 'SELECT "targetAccountId" AS "id" FROM "accountBlocklist" WHERE "accountId" IN (' + blockerIdsString + ')' +
        ' UNION ' +
        'SELECT "account"."id" AS "id" FROM account INNER JOIN "actor" ON account."actorId" = actor.id ' +
        'INNER JOIN "serverBlocklist" ON "actor"."serverId" = "serverBlocklist"."targetServerId" ' +
        'WHERE "serverBlocklist"."accountId" IN (' + blockerIdsString + ')';
}
exports.buildBlockedAccountSQL = buildBlockedAccountSQL;
function buildServerIdsFollowedBy(actorId) {
    const actorIdNumber = (0, core_utils_1.forceNumber)(actorId);
    return '(' +
        'SELECT "actor"."serverId" FROM "actorFollow" ' +
        'INNER JOIN "actor" ON actor.id = "actorFollow"."targetActorId" ' +
        'WHERE "actorFollow"."actorId" = ' + actorIdNumber +
        ')';
}
exports.buildServerIdsFollowedBy = buildServerIdsFollowedBy;
function buildSQLAttributes(options) {
    const { model, tableName, aliasPrefix, excludeAttributes } = options;
    const attributes = Object.keys(model.getAttributes());
    return attributes
        .filter(a => {
        if (!excludeAttributes)
            return true;
        if (excludeAttributes.includes(a))
            return false;
        return true;
    })
        .map(a => {
        return `"${tableName}"."${a}" AS "${aliasPrefix || ''}${a}"`;
    });
}
exports.buildSQLAttributes = buildSQLAttributes;
//# sourceMappingURL=sql.js.map