"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const server_commands_1 = require("../../../../shared/server-commands");
describe('Test users API validators', function () {
    let server;
    before(function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this.timeout(30000);
            server = yield (0, server_commands_1.createSingleServer)(1, {
                rates_limit: {
                    ask_send_email: {
                        max: 10
                    }
                }
            });
            yield (0, server_commands_1.setAccessTokensToServers)([server]);
            yield server.config.enableSignup(true);
            yield server.users.generate('moderator2', 1);
            yield server.registrations.requestRegistration({
                username: 'request1',
                registrationReason: 'tt'
            });
        });
    });
    describe('When asking a password reset', function () {
        const path = '/api/v1/users/ask-reset-password';
        it('Should fail with a missing email', function () {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                const fields = {};
                yield (0, server_commands_1.makePostBodyRequest)({ url: server.url, path, fields });
            });
        });
        it('Should fail with an invalid email', function () {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                const fields = { email: 'hello' };
                yield (0, server_commands_1.makePostBodyRequest)({ url: server.url, path, fields });
            });
        });
        it('Should success with the correct params', function () {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                const fields = { email: 'admin@example.com' };
                yield (0, server_commands_1.makePostBodyRequest)({
                    url: server.url,
                    path,
                    fields,
                    expectedStatus: 204
                });
            });
        });
    });
    describe('When asking for an account verification email', function () {
        const path = '/api/v1/users/ask-send-verify-email';
        it('Should fail with a missing email', function () {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                const fields = {};
                yield (0, server_commands_1.makePostBodyRequest)({ url: server.url, path, fields });
            });
        });
        it('Should fail with an invalid email', function () {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                const fields = { email: 'hello' };
                yield (0, server_commands_1.makePostBodyRequest)({ url: server.url, path, fields });
            });
        });
        it('Should succeed with the correct params', function () {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                const fields = { email: 'admin@example.com' };
                yield (0, server_commands_1.makePostBodyRequest)({
                    url: server.url,
                    path,
                    fields,
                    expectedStatus: 204
                });
            });
        });
    });
    describe('When asking for a registration verification email', function () {
        const path = '/api/v1/users/registrations/ask-send-verify-email';
        it('Should fail with a missing email', function () {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                const fields = {};
                yield (0, server_commands_1.makePostBodyRequest)({ url: server.url, path, fields });
            });
        });
        it('Should fail with an invalid email', function () {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                const fields = { email: 'hello' };
                yield (0, server_commands_1.makePostBodyRequest)({ url: server.url, path, fields });
            });
        });
        it('Should succeed with the correct params', function () {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                const fields = { email: 'request1@example.com' };
                yield (0, server_commands_1.makePostBodyRequest)({
                    url: server.url,
                    path,
                    fields,
                    expectedStatus: 204
                });
            });
        });
    });
    after(function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield (0, server_commands_1.cleanupTests)([server]);
        });
    });
});
//# sourceMappingURL=users-emails.js.map