"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const shared_1 = require("../../shared");
const server_commands_1 = require("../../../../shared/server-commands");
describe('Test registrations notifications', function () {
    let server;
    let userToken1;
    let userNotifications = [];
    let adminNotifications = [];
    let emails = [];
    let baseParams;
    before(function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this.timeout(120000);
            const res = yield (0, shared_1.prepareNotificationsTest)(1);
            server = res.servers[0];
            emails = res.emails;
            userToken1 = res.userAccessToken;
            adminNotifications = res.adminNotifications;
            userNotifications = res.userNotifications;
            baseParams = {
                server,
                emails,
                socketNotifications: adminNotifications,
                token: server.accessToken
            };
        });
    });
    describe('New direct registration for moderators', function () {
        before(function () {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                yield server.config.enableSignup(false);
            });
        });
        it('Should send a notification only to moderators when a user registers on the instance', function () {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                this.timeout(50000);
                yield server.registrations.register({ username: 'user_10' });
                yield (0, server_commands_1.waitJobs)([server]);
                yield (0, shared_1.checkUserRegistered)(Object.assign(Object.assign({}, baseParams), { username: 'user_10', checkType: 'presence' }));
                const userOverride = { socketNotifications: userNotifications, token: userToken1, check: { web: true, mail: false } };
                yield (0, shared_1.checkUserRegistered)(Object.assign(Object.assign(Object.assign({}, baseParams), userOverride), { username: 'user_10', checkType: 'absence' }));
            });
        });
    });
    describe('New registration request for moderators', function () {
        before(function () {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                yield server.config.enableSignup(true);
            });
        });
        it('Should send a notification on new registration request', function () {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                this.timeout(50000);
                const registrationReason = 'my reason';
                yield server.registrations.requestRegistration({ username: 'user_11', registrationReason });
                yield (0, server_commands_1.waitJobs)([server]);
                yield (0, shared_1.checkRegistrationRequest)(Object.assign(Object.assign({}, baseParams), { username: 'user_11', registrationReason, checkType: 'presence' }));
                const userOverride = { socketNotifications: userNotifications, token: userToken1, check: { web: true, mail: false } };
                yield (0, shared_1.checkRegistrationRequest)(Object.assign(Object.assign(Object.assign({}, baseParams), userOverride), { username: 'user_11', registrationReason, checkType: 'absence' }));
            });
        });
    });
    after(function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            shared_1.MockSmtpServer.Instance.kill();
            yield (0, server_commands_1.cleanupTests)([server]);
        });
    });
});
//# sourceMappingURL=registrations-notifications.js.map