"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chai_1 = require("chai");
const shared_1 = require("../shared");
const server_commands_1 = require("../../../shared/server-commands");
describe('Test peertube-runner program client CLI', function () {
    let server;
    let peertubeRunner;
    before(function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this.timeout(120000);
            server = yield (0, server_commands_1.createSingleServer)(1);
            yield (0, server_commands_1.setAccessTokensToServers)([server]);
            yield (0, server_commands_1.setDefaultVideoChannel)([server]);
            yield server.config.enableRemoteTranscoding();
            peertubeRunner = new shared_1.PeerTubeRunnerProcess(server);
            yield peertubeRunner.runServer();
        });
    });
    it('Should not have PeerTube instance listed', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const data = yield peertubeRunner.listRegisteredPeerTubeInstances();
            (0, chai_1.expect)(data).to.not.contain(server.url);
        });
    });
    it('Should register a new PeerTube instance', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const registrationToken = yield server.runnerRegistrationTokens.getFirstRegistrationToken();
            yield peertubeRunner.registerPeerTubeInstance({
                registrationToken,
                runnerName: 'my super runner',
                runnerDescription: 'super description'
            });
        });
    });
    it('Should list this new PeerTube instance', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const data = yield peertubeRunner.listRegisteredPeerTubeInstances();
            (0, chai_1.expect)(data).to.contain(server.url);
            (0, chai_1.expect)(data).to.contain('my super runner');
            (0, chai_1.expect)(data).to.contain('super description');
        });
    });
    it('Should still have the configuration after a restart', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            peertubeRunner.kill();
            yield peertubeRunner.runServer();
        });
    });
    it('Should unregister the PeerTube instance', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield peertubeRunner.unregisterPeerTubeInstance({ runnerName: 'my super runner' });
        });
    });
    it('Should not have PeerTube instance listed', function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const data = yield peertubeRunner.listRegisteredPeerTubeInstances();
            (0, chai_1.expect)(data).to.not.contain(server.url);
        });
    });
    after(function () {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            peertubeRunner.kill();
            yield (0, server_commands_1.cleanupTests)([server]);
        });
    });
});
//# sourceMappingURL=client-cli.js.map