"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkPeerTubeRunnerCacheIsEmpty = exports.checkDirectoryIsEmpty = exports.checkPersistentTmpIsEmpty = exports.checkTmpIsEmpty = void 0;
const tslib_1 = require("tslib");
const chai_1 = require("chai");
const fs_extra_1 = require("fs-extra");
const os_1 = require("os");
const path_1 = require("path");
function checkTmpIsEmpty(server) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield checkDirectoryIsEmpty(server, 'tmp', ['plugins-global.css', 'hls', 'resumable-uploads']);
        if (yield (0, fs_extra_1.pathExists)(server.getDirectoryPath('tmp/hls'))) {
            yield checkDirectoryIsEmpty(server, 'tmp/hls');
        }
    });
}
exports.checkTmpIsEmpty = checkTmpIsEmpty;
function checkPersistentTmpIsEmpty(server) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield checkDirectoryIsEmpty(server, 'tmp-persistent');
    });
}
exports.checkPersistentTmpIsEmpty = checkPersistentTmpIsEmpty;
function checkDirectoryIsEmpty(server, directory, exceptions = []) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const directoryPath = server.getDirectoryPath(directory);
        const directoryExists = yield (0, fs_extra_1.pathExists)(directoryPath);
        (0, chai_1.expect)(directoryExists).to.be.true;
        const files = yield (0, fs_extra_1.readdir)(directoryPath);
        const filtered = files.filter(f => exceptions.includes(f) === false);
        (0, chai_1.expect)(filtered).to.have.lengthOf(0);
    });
}
exports.checkDirectoryIsEmpty = checkDirectoryIsEmpty;
function checkPeerTubeRunnerCacheIsEmpty(runner) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const directoryPath = (0, path_1.join)((0, os_1.homedir)(), '.cache', 'peertube-runner-nodejs', runner.getId(), 'transcoding');
        const directoryExists = yield (0, fs_extra_1.pathExists)(directoryPath);
        (0, chai_1.expect)(directoryExists).to.be.true;
        const files = yield (0, fs_extra_1.readdir)(directoryPath);
        (0, chai_1.expect)(files, 'Directory content: ' + files.join(', ')).to.have.lengthOf(0);
    });
}
exports.checkPeerTubeRunnerCacheIsEmpty = checkPeerTubeRunnerCacheIsEmpty;
//# sourceMappingURL=directories.js.map