"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PeerTubeRunnerProcess = void 0;
const tslib_1 = require("tslib");
const child_process_1 = require("child_process");
const execa_1 = tslib_1.__importDefault(require("execa"));
const path_1 = require("path");
const core_utils_1 = require("../../../shared/core-utils");
class PeerTubeRunnerProcess {
    constructor(server) {
        this.server = server;
    }
    runServer(options = {}) {
        const { hideLogs = true } = options;
        return new Promise((res, rej) => {
            const args = ['server', '--verbose', ...this.buildIdArg()];
            const forkOptions = {
                detached: false,
                silent: true
            };
            this.app = (0, child_process_1.fork)(this.getRunnerPath(), args, forkOptions);
            this.app.stdout.on('data', data => {
                const str = data.toString();
                if (!hideLogs) {
                    console.log(str);
                }
            });
            res();
        });
    }
    registerPeerTubeInstance(options) {
        const { registrationToken, runnerName, runnerDescription } = options;
        const args = [
            'register',
            '--url', this.server.url,
            '--registration-token', registrationToken,
            '--runner-name', runnerName,
            ...this.buildIdArg()
        ];
        if (runnerDescription) {
            args.push('--runner-description');
            args.push(runnerDescription);
        }
        return execa_1.default.node(this.getRunnerPath(), args);
    }
    unregisterPeerTubeInstance(options) {
        const { runnerName } = options;
        const args = ['unregister', '--url', this.server.url, '--runner-name', runnerName, ...this.buildIdArg()];
        return execa_1.default.node(this.getRunnerPath(), args);
    }
    listRegisteredPeerTubeInstances() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const args = ['list-registered', ...this.buildIdArg()];
            const { stdout } = yield execa_1.default.node(this.getRunnerPath(), args);
            return stdout;
        });
    }
    kill() {
        if (!this.app)
            return;
        process.kill(this.app.pid);
        this.app = null;
    }
    getId() {
        return 'test-' + this.server.internalServerNumber;
    }
    getRunnerPath() {
        return (0, path_1.join)((0, core_utils_1.root)(), 'packages', 'peertube-runner', 'dist', 'peertube-runner.js');
    }
    buildIdArg() {
        return ['--id', this.getId()];
    }
}
exports.PeerTubeRunnerProcess = PeerTubeRunnerProcess;
//# sourceMappingURL=peertube-runner-process.js.map