"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseTorrentVideo = exports.checkWebTorrentWorks = void 0;
const tslib_1 = require("tslib");
const chai_1 = require("chai");
const fs_extra_1 = require("fs-extra");
const parse_torrent_1 = tslib_1.__importDefault(require("parse-torrent"));
const path_1 = require("path");
let webtorrent;
function checkWebTorrentWorks(magnetUri, pathMatch) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const torrent = yield webtorrentAdd(magnetUri, true);
        (0, chai_1.expect)(torrent.files).to.be.an('array');
        (0, chai_1.expect)(torrent.files.length).to.equal(1);
        (0, chai_1.expect)(torrent.files[0].path).to.exist.and.to.not.equal('');
        if (pathMatch) {
            (0, chai_1.expect)(torrent.files[0].path).match(pathMatch);
        }
    });
}
exports.checkWebTorrentWorks = checkWebTorrentWorks;
function parseTorrentVideo(server, file) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const torrentName = (0, path_1.basename)(file.torrentUrl);
        const torrentPath = server.servers.buildDirectory((0, path_1.join)('torrents', torrentName));
        const data = yield (0, fs_extra_1.readFile)(torrentPath);
        return (0, parse_torrent_1.default)(data);
    });
}
exports.parseTorrentVideo = parseTorrentVideo;
function webtorrentAdd(torrentId, refreshWebTorrent = false) {
    const WebTorrent = require('webtorrent');
    if (webtorrent && refreshWebTorrent)
        webtorrent.destroy();
    if (!webtorrent || refreshWebTorrent)
        webtorrent = new WebTorrent();
    webtorrent.on('error', err => console.error('Error in webtorrent', err));
    return new Promise(res => {
        const torrent = webtorrent.add(torrentId, res);
        torrent.on('error', err => console.error('Error in webtorrent torrent', err));
        torrent.on('warning', warn => {
            const msg = typeof warn === 'string'
                ? warn
                : warn.message;
            if (msg.includes('Unsupported'))
                return;
            console.error('Warning in webtorrent torrent', warn);
        });
    });
}
//# sourceMappingURL=webtorrent.js.map