"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FFmpegImage = void 0;
const tslib_1 = require("tslib");
const ffmpeg_command_wrapper_1 = require("./ffmpeg-command-wrapper");
class FFmpegImage {
    constructor(options) {
        this.commandWrapper = new ffmpeg_command_wrapper_1.FFmpegCommandWrapper(options);
    }
    convertWebPToJPG(options) {
        const { path, destination } = options;
        this.commandWrapper.buildCommand(path)
            .output(destination);
        return this.commandWrapper.runCommand({ silent: true });
    }
    processGIF(options) {
        const { path, destination, newSize } = options;
        this.commandWrapper.buildCommand(path)
            .fps(20)
            .size(`${newSize.width}x${newSize.height}`)
            .output(destination);
        return this.commandWrapper.runCommand();
    }
    generateThumbnailFromVideo(options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { fromPath, folder, imageName } = options;
            const pendingImageName = 'pending-' + imageName;
            const thumbnailOptions = {
                filename: pendingImageName,
                count: 1,
                folder
            };
            return new Promise((res, rej) => {
                this.commandWrapper.buildCommand(fromPath)
                    .on('error', rej)
                    .on('end', () => res(imageName))
                    .thumbnail(thumbnailOptions);
            });
        });
    }
}
exports.FFmpegImage = FFmpegImage;
//# sourceMappingURL=ffmpeg-images.js.map