"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.presetOnlyAudio = exports.presetCopy = exports.presetVOD = void 0;
const tslib_1 = require("tslib");
const core_utils_1 = require("../../core-utils");
const ffprobe_1 = require("../ffprobe");
const encoder_options_1 = require("./encoder-options");
const ffmpeg_utils_1 = require("../ffmpeg-utils");
function presetVOD(options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { commandWrapper, input, resolution, fps, scaleFilterValue } = options;
        const command = commandWrapper.getCommand();
        command.format('mp4')
            .outputOption('-movflags faststart');
        (0, encoder_options_1.addDefaultEncoderGlobalParams)(command);
        const probe = yield (0, ffprobe_1.ffprobePromise)(input);
        const bitrate = yield (0, ffprobe_1.getVideoStreamBitrate)(input, probe);
        const videoStreamDimensions = yield (0, ffprobe_1.getVideoStreamDimensionsInfo)(input, probe);
        let streamsToProcess = ['audio', 'video'];
        if (!(yield (0, ffprobe_1.hasAudioStream)(input, probe))) {
            command.noAudio();
            streamsToProcess = ['video'];
        }
        for (const streamType of streamsToProcess) {
            const builderResult = yield commandWrapper.getEncoderBuilderResult(Object.assign(Object.assign({}, (0, core_utils_1.pick)(options, ['canCopyAudio', 'canCopyVideo'])), { input, inputBitrate: bitrate, inputRatio: (videoStreamDimensions === null || videoStreamDimensions === void 0 ? void 0 : videoStreamDimensions.ratio) || 0, resolution,
                fps,
                streamType, videoType: 'vod' }));
            if (!builderResult) {
                throw new Error('No available encoder found for stream ' + streamType);
            }
            commandWrapper.debugLog(`Apply ffmpeg params from ${builderResult.encoder} for ${streamType} ` +
                `stream of input ${input} using ${commandWrapper.getProfile()} profile.`, { builderResult, resolution, fps });
            if (streamType === 'video') {
                command.videoCodec(builderResult.encoder);
                if (scaleFilterValue) {
                    command.outputOption(`-vf ${(0, ffmpeg_utils_1.getScaleFilter)(builderResult.result)}=${scaleFilterValue}`);
                }
            }
            else if (streamType === 'audio') {
                command.audioCodec(builderResult.encoder);
            }
            (0, encoder_options_1.applyEncoderOptions)(command, builderResult.result);
            (0, encoder_options_1.addDefaultEncoderParams)({ command, encoder: builderResult.encoder, fps });
        }
    });
}
exports.presetVOD = presetVOD;
function presetCopy(commandWrapper) {
    commandWrapper.getCommand()
        .format('mp4')
        .videoCodec('copy')
        .audioCodec('copy');
}
exports.presetCopy = presetCopy;
function presetOnlyAudio(commandWrapper) {
    commandWrapper.getCommand()
        .format('mp4')
        .audioCodec('copy')
        .noVideo();
}
exports.presetOnlyAudio = presetOnlyAudio;
//# sourceMappingURL=presets.js.map