"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RunnerJobsCommand = void 0;
const tslib_1 = require("tslib");
const core_utils_1 = require("../../core-utils");
const models_1 = require("../../models");
const requests_1 = require("../requests");
const server_1 = require("../server");
const shared_1 = require("../shared");
class RunnerJobsCommand extends shared_1.AbstractCommand {
    list(options = {}) {
        const path = '/api/v1/runners/jobs';
        return this.getRequestBody(Object.assign(Object.assign({}, options), { path, query: (0, core_utils_1.pick)(options, ['start', 'count', 'sort', 'search']), implicitToken: true, defaultExpectedStatus: 200 }));
    }
    cancelByAdmin(options) {
        const path = '/api/v1/runners/jobs/' + options.jobUUID + '/cancel';
        return this.postBodyRequest(Object.assign(Object.assign({}, options), { path, implicitToken: true, defaultExpectedStatus: 204 }));
    }
    request(options) {
        const path = '/api/v1/runners/jobs/request';
        return (0, requests_1.unwrapBody)(this.postBodyRequest(Object.assign(Object.assign({}, options), { path, fields: (0, core_utils_1.pick)(options, ['runnerToken']), implicitToken: false, defaultExpectedStatus: 200 })));
    }
    requestVOD(options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const vodTypes = new Set(['vod-audio-merge-transcoding', 'vod-hls-transcoding', 'vod-web-video-transcoding']);
            const { availableJobs } = yield this.request(options);
            return {
                availableJobs: availableJobs.filter(j => vodTypes.has(j.type))
            };
        });
    }
    requestLive(options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const vodTypes = new Set(['live-rtmp-hls-transcoding']);
            const { availableJobs } = yield this.request(options);
            return {
                availableJobs: availableJobs.filter(j => vodTypes.has(j.type))
            };
        });
    }
    accept(options) {
        const path = '/api/v1/runners/jobs/' + options.jobUUID + '/accept';
        return (0, requests_1.unwrapBody)(this.postBodyRequest(Object.assign(Object.assign({}, options), { path, fields: (0, core_utils_1.pick)(options, ['runnerToken']), implicitToken: false, defaultExpectedStatus: 200 })));
    }
    abort(options) {
        const path = '/api/v1/runners/jobs/' + options.jobUUID + '/abort';
        return this.postBodyRequest(Object.assign(Object.assign({}, options), { path, fields: (0, core_utils_1.pick)(options, ['reason', 'jobToken', 'runnerToken']), implicitToken: false, defaultExpectedStatus: 204 }));
    }
    update(options) {
        const path = '/api/v1/runners/jobs/' + options.jobUUID + '/update';
        const { payload } = options;
        const attaches = {};
        let payloadWithoutFiles = payload;
        if ((0, models_1.isLiveRTMPHLSTranscodingUpdatePayload)(payload)) {
            if (payload.masterPlaylistFile) {
                attaches[`payload[masterPlaylistFile]`] = payload.masterPlaylistFile;
            }
            attaches[`payload[resolutionPlaylistFile]`] = payload.resolutionPlaylistFile;
            attaches[`payload[videoChunkFile]`] = payload.videoChunkFile;
            payloadWithoutFiles = (0, core_utils_1.omit)(payloadWithoutFiles, ['masterPlaylistFile', 'resolutionPlaylistFile', 'videoChunkFile']);
        }
        return this.postUploadRequest(Object.assign(Object.assign({}, options), { path, fields: Object.assign(Object.assign({}, (0, core_utils_1.pick)(options, ['progress', 'jobToken', 'runnerToken'])), { payload: payloadWithoutFiles }), attaches, implicitToken: false, defaultExpectedStatus: 204 }));
    }
    error(options) {
        const path = '/api/v1/runners/jobs/' + options.jobUUID + '/error';
        return this.postBodyRequest(Object.assign(Object.assign({}, options), { path, fields: (0, core_utils_1.pick)(options, ['message', 'jobToken', 'runnerToken']), implicitToken: false, defaultExpectedStatus: 204 }));
    }
    success(options) {
        const { payload } = options;
        const path = '/api/v1/runners/jobs/' + options.jobUUID + '/success';
        const attaches = {};
        let payloadWithoutFiles = payload;
        if (((0, models_1.isWebVideoOrAudioMergeTranscodingPayloadSuccess)(payload) || (0, models_1.isHLSTranscodingPayloadSuccess)(payload)) && payload.videoFile) {
            attaches[`payload[videoFile]`] = payload.videoFile;
            payloadWithoutFiles = (0, core_utils_1.omit)(payloadWithoutFiles, ['videoFile']);
        }
        if ((0, models_1.isHLSTranscodingPayloadSuccess)(payload) && payload.resolutionPlaylistFile) {
            attaches[`payload[resolutionPlaylistFile]`] = payload.resolutionPlaylistFile;
            payloadWithoutFiles = (0, core_utils_1.omit)(payloadWithoutFiles, ['resolutionPlaylistFile']);
        }
        return this.postUploadRequest(Object.assign(Object.assign({}, options), { path,
            attaches, fields: Object.assign(Object.assign({}, (0, core_utils_1.pick)(options, ['jobToken', 'runnerToken'])), { payload: payloadWithoutFiles }), implicitToken: false, defaultExpectedStatus: 204 }));
    }
    getJobFile(options) {
        const { host, protocol, pathname } = new URL(options.url);
        return this.postBodyRequest({
            url: `${protocol}//${host}`,
            path: pathname,
            fields: (0, core_utils_1.pick)(options, ['jobToken', 'runnerToken']),
            implicitToken: false,
            defaultExpectedStatus: 200
        });
    }
    autoAccept(options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { availableJobs } = yield this.request(options);
            const job = options.type
                ? availableJobs.find(j => j.type === options.type)
                : availableJobs[0];
            return this.accept(Object.assign(Object.assign({}, options), { jobUUID: job.uuid }));
        });
    }
    autoProcessWebVideoJob(runnerToken, jobUUIDToProcess) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let jobUUID = jobUUIDToProcess;
            if (!jobUUID) {
                const { availableJobs } = yield this.request({ runnerToken });
                jobUUID = availableJobs[0].uuid;
            }
            const { job } = yield this.accept({ runnerToken, jobUUID });
            const jobToken = job.jobToken;
            const payload = { videoFile: 'video_short.mp4' };
            yield this.success({ runnerToken, jobUUID, jobToken, payload });
            yield (0, server_1.waitJobs)([this.server]);
            return job;
        });
    }
    cancelAllJobs(options = {}) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { state } = options;
            const { data } = yield this.list({ count: 100 });
            const allowedStates = new Set([
                models_1.RunnerJobState.PENDING,
                models_1.RunnerJobState.PROCESSING,
                models_1.RunnerJobState.WAITING_FOR_PARENT_JOB
            ]);
            for (const job of data) {
                if (state && job.state.id !== state)
                    continue;
                else if (allowedStates.has(job.state.id) !== true)
                    continue;
                yield this.cancelByAdmin({ jobUUID: job.uuid });
            }
        });
    }
    getJob(options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { data } = yield this.list(Object.assign(Object.assign({}, options), { count: 100, sort: '-updatedAt' }));
            return data.find(j => j.uuid === options.uuid);
        });
    }
    requestLiveJob(runnerToken) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            let availableJobs = [];
            while (availableJobs.length === 0) {
                const result = yield this.requestLive({ runnerToken });
                availableJobs = result.availableJobs;
                if (availableJobs.length === 1)
                    break;
                yield (0, core_utils_1.wait)(150);
            }
            return availableJobs[0];
        });
    }
}
exports.RunnerJobsCommand = RunnerJobsCommand;
//# sourceMappingURL=runner-jobs-command.js.map