"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ObjectStorageCommand = void 0;
const tslib_1 = require("tslib");
const crypto_1 = require("crypto");
const requests_1 = require("../requests");
class ObjectStorageCommand {
    constructor() {
        this.bucketsCreated = [];
        this.seed = (0, crypto_1.randomInt)(0, 10000);
    }
    static getMockCredentialsConfig() {
        return {
            access_key_id: 'AKIAIOSFODNN7EXAMPLE',
            secret_access_key: 'wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY'
        };
    }
    static getMockEndpointHost() {
        return 'localhost:9444';
    }
    static getMockRegion() {
        return 'us-east-1';
    }
    getDefaultMockConfig() {
        return {
            object_storage: {
                enabled: true,
                endpoint: 'http://' + ObjectStorageCommand.getMockEndpointHost(),
                region: ObjectStorageCommand.getMockRegion(),
                credentials: ObjectStorageCommand.getMockCredentialsConfig(),
                streaming_playlists: {
                    bucket_name: this.getMockStreamingPlaylistsBucketName()
                },
                videos: {
                    bucket_name: this.getMockWebVideosBucketName()
                }
            }
        };
    }
    getMockWebVideosBaseUrl() {
        return `http://${this.getMockWebVideosBucketName()}.${ObjectStorageCommand.getMockEndpointHost()}/`;
    }
    getMockPlaylistBaseUrl() {
        return `http://${this.getMockStreamingPlaylistsBucketName()}.${ObjectStorageCommand.getMockEndpointHost()}/`;
    }
    prepareDefaultMockBuckets() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield this.createMockBucket(this.getMockStreamingPlaylistsBucketName());
            yield this.createMockBucket(this.getMockWebVideosBucketName());
        });
    }
    createMockBucket(name) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this.bucketsCreated.push(name);
            yield this.deleteMockBucket(name);
            yield (0, requests_1.makePostBodyRequest)({
                url: ObjectStorageCommand.getMockEndpointHost(),
                path: '/ui/' + name + '?create',
                expectedStatus: 307
            });
            yield (0, requests_1.makePostBodyRequest)({
                url: ObjectStorageCommand.getMockEndpointHost(),
                path: '/ui/' + name + '?make-public',
                expectedStatus: 307
            });
        });
    }
    cleanupMock() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            for (const name of this.bucketsCreated) {
                yield this.deleteMockBucket(name);
            }
        });
    }
    getMockStreamingPlaylistsBucketName(name = 'streaming-playlists') {
        return this.getMockBucketName(name);
    }
    getMockWebVideosBucketName(name = 'web-videos') {
        return this.getMockBucketName(name);
    }
    getMockBucketName(name) {
        return `${this.seed}-${name}`;
    }
    deleteMockBucket(name) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield (0, requests_1.makePostBodyRequest)({
                url: ObjectStorageCommand.getMockEndpointHost(),
                path: '/ui/' + name + '?delete',
                expectedStatus: 307
            });
        });
    }
    static getDefaultScalewayConfig(options) {
        const { serverNumber, enablePrivateProxy = true, privateACL = 'private' } = options;
        return {
            object_storage: {
                enabled: true,
                endpoint: this.getScalewayEndpointHost(),
                region: this.getScalewayRegion(),
                credentials: this.getScalewayCredentialsConfig(),
                upload_acl: {
                    private: privateACL
                },
                proxy: {
                    proxify_private_files: enablePrivateProxy
                },
                streaming_playlists: {
                    bucket_name: this.DEFAULT_SCALEWAY_BUCKET,
                    prefix: `test:server-${serverNumber}-streaming-playlists:`
                },
                videos: {
                    bucket_name: this.DEFAULT_SCALEWAY_BUCKET,
                    prefix: `test:server-${serverNumber}-videos:`
                }
            }
        };
    }
    static getScalewayCredentialsConfig() {
        return {
            access_key_id: process.env.OBJECT_STORAGE_SCALEWAY_KEY_ID,
            secret_access_key: process.env.OBJECT_STORAGE_SCALEWAY_ACCESS_KEY
        };
    }
    static getScalewayEndpointHost() {
        return 's3.fr-par.scw.cloud';
    }
    static getScalewayRegion() {
        return 'fr-par';
    }
    static getScalewayBaseUrl() {
        return `https://${this.DEFAULT_SCALEWAY_BUCKET}.${this.getScalewayEndpointHost()}/`;
    }
}
ObjectStorageCommand.DEFAULT_SCALEWAY_BUCKET = 'peertube-ci-test';
exports.ObjectStorageCommand = ObjectStorageCommand;
//# sourceMappingURL=object-storage-command.js.map