"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RegistrationsCommand = void 0;
const core_utils_1 = require("../../core-utils");
const requests_1 = require("../requests");
const shared_1 = require("../shared");
class RegistrationsCommand extends shared_1.AbstractCommand {
    register(options) {
        const { password = 'password', email = options.username + '@example.com' } = options;
        const path = '/api/v1/users/register';
        return this.postBodyRequest(Object.assign(Object.assign({}, options), { path, fields: Object.assign(Object.assign({}, (0, core_utils_1.pick)(options, ['username', 'displayName', 'channel'])), { password,
                email }), implicitToken: false, defaultExpectedStatus: 204 }));
    }
    requestRegistration(options) {
        const { password = 'password', email = options.username + '@example.com' } = options;
        const path = '/api/v1/users/registrations/request';
        return (0, requests_1.unwrapBody)(this.postBodyRequest(Object.assign(Object.assign({}, options), { path, fields: Object.assign(Object.assign({}, (0, core_utils_1.pick)(options, ['username', 'displayName', 'channel', 'registrationReason'])), { password,
                email }), implicitToken: false, defaultExpectedStatus: 200 })));
    }
    accept(options) {
        const { id } = options;
        const path = '/api/v1/users/registrations/' + id + '/accept';
        return this.postBodyRequest(Object.assign(Object.assign({}, options), { path, fields: (0, core_utils_1.pick)(options, ['moderationResponse', 'preventEmailDelivery']), implicitToken: true, defaultExpectedStatus: 204 }));
    }
    reject(options) {
        const { id } = options;
        const path = '/api/v1/users/registrations/' + id + '/reject';
        return this.postBodyRequest(Object.assign(Object.assign({}, options), { path, fields: (0, core_utils_1.pick)(options, ['moderationResponse', 'preventEmailDelivery']), implicitToken: true, defaultExpectedStatus: 204 }));
    }
    delete(options) {
        const { id } = options;
        const path = '/api/v1/users/registrations/' + id;
        return this.deleteRequest(Object.assign(Object.assign({}, options), { path, implicitToken: true, defaultExpectedStatus: 204 }));
    }
    list(options = {}) {
        const path = '/api/v1/users/registrations';
        return this.getRequestBody(Object.assign(Object.assign({}, options), { path, query: (0, core_utils_1.pick)(options, ['start', 'count', 'sort', 'search']), implicitToken: true, defaultExpectedStatus: 200 }));
    }
    askSendVerifyEmail(options) {
        const { email } = options;
        const path = '/api/v1/users/registrations/ask-send-verify-email';
        return this.postBodyRequest(Object.assign(Object.assign({}, options), { path, fields: { email }, implicitToken: false, defaultExpectedStatus: 204 }));
    }
    verifyEmail(options) {
        const { registrationId, verificationString } = options;
        const path = '/api/v1/users/registrations/' + registrationId + '/verify-email';
        return this.postBodyRequest(Object.assign(Object.assign({}, options), { path, fields: {
                verificationString
            }, implicitToken: false, defaultExpectedStatus: 204 }));
    }
}
exports.RegistrationsCommand = RegistrationsCommand;
//# sourceMappingURL=registrations-command.js.map